
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']


def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    pass


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    pass


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s*\x00\x00\x00z\x04e\x00\x01\x00W\x00n\x07\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01e\x00e\x02e\x03d\x01d\x02'
        b'\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds[+\x00\x00PYARMOR\x00\x00\x03\n\x00o\r\r\n\t0\xe0\x02\x00'
        b'\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x1b+\x00\x00\x00\x00\x00\x00\x07nE>\xc7\xdd\t^C\xdf\xf64\xc5\xe5u\xd4\x00\x00\x00\x00\x00\x00\x00\x00\x19\xfc\xe5\xc6c\x91\x87O\xef\x11\x0ck\x8c\xb7\x9e\xc5ke\x0b:\x1a'
        b"~\x00c\xf9'\xd5\x177:\xcem\x06\x8b*\xdc\xea\x8e\x9e9\xa8\x1d\xe2\x8duQ\x1esFps\xde\xad\x9b1WRd\x1a\xec\xdfe\x9b'\x0fQZ\xacr(\xe7v?g\x9c\xde\x81g\xa70\x8aW\x82\x11\xdc"
        b'\xfb\x9c\xbd\x86i\xda\xaa\xb9\x8e\xc2\xff\xb7\x7f"\x1dm\r"3\x88\x1a/\x81\xe1(\xc4\xe9\xe2]\xdfc\xcb)\xa5A0>\x0fW\xc5\\u(eRD\xcc\\\xea\x81DN\xcb g\xd6G6{H\x89\x98\xee\x14'
        b'\xc1\xebZT^\xdd>{q\xa5\x8bA\xbc5J,2?Z5\xf9VD\x16*\xc2\xa9\x85\x8ah\xfei\xdfx\xa7\x1a\xc1\x91\xf9\xe7\xd1\x0c3,\x94\x06\x02U\xa4b\xc0s\xe9A\x1fLt\xdd\x16\xdb\xf8W8\x8a'
        b'\x8a\xf0_&A\xceS\xc5\xef\x8dM=\x95,y>\x82\xcd\xbc\xd6\x81\xb7\x01\xc5M,/\x1afA g[!H\x13\xe0\x8c\xe1\xbd\xef\n\xce\xa5(\x97\xf8\\RA+\xb8CP\x0b\x90\x9f\x91\xec\x177i\xd2\xa1'
        b'\xc6\xae\xcc-lOX\x8bt,\xd5\xc3\x995\xe2\xd3E\x7fh\xf2%3\xac\xd7\x1a\xf0c\x91F\xc4"x\\vT.@\xf2z\xc4\xbd*-%\xd0\x07\xddC\x80t\x1b\xc1{\xba\x1e\x81\t\xf9\xac\xfd\xa7\xa4\xf3\x88'
        b'\x0f\x91_"\x0f\xceq\xdd\x8f\xb2\x91\xb8N\xa6\xb6\xeb\xb6\xf1Y]\xf4\xec\xa8\x08F\x84\x89E\xb1\xd6S;\xffI\xb1\xb1D\x841\x8c<\xc3\x9f\xdf\xd2\xe4\xc6\x8e]\xd0n\xf9\x96b\x8a\xd5\x8f\x90\xb1H\x98&\xd4\xe4'
        b'\xde)\xc2\xb8\x13b\x12\xba/@\xcd\xbf\x08\x82\xc9\xb8w\x8d\xa3\xa2u\xd1gVYt\x12m\xf303\xad\xea[\xb4\xe0\xcbWpY\x18\x90d\x1ah\xab\x86( \xcb\x8cl\x8dTnG\xe0Os\xc4D\xd3\x99\xb4'
        b'\x92\xc3kq\xe9\xde\xdf\xf0\xff\x147\xba]\xa6\xf1\xe2\xbf\xec\xc7\xd0\xc4Y\x1b?\x0c\xa1G\x98\xec\xf1\xe1PwY\xe4\xde\x1c\x80\xba1\xeaTt,\xe6\xc2\xde+\x0f\x04\xad\x0c\x8dK\x9a\xf4tj\x9a\xa3\x99\xcd\xd1v'
        b"\x8eU\xc0\x8c\x1cr\xf3\x9cd\x17\xc1\x07\x9d\x93\x84_\xab,\xb2i,\x16\xd9\x1a\xc8\x8e\xde\xfc~\xa1\xfa\x89\xc8\x9eb\xa2.\xdap\xbbKM\xb4\xca\xd1SE\xd6\x97_\xa9\xfb_{\x94!`*Y',\x10\xb6\xb2"
        b'|\xeei=\xfb\x00\x05\xd3\xc1\x01\xea\x10_\x0e\xbc\x1f\x92\xf6^\x8bX\x0b\xfc\xfce\xab\xe6\xf4\xc6\xcc\x05Wq\x84\x12\x06=\xc9\x1cg\x03\x9c\x83\x98~/\xf8\xbc\x1a(\xff\xdb\x1aU\xe5y\x88\x178\xbf\x04OT7'
        b'\xe7d<\xe5\xa2\xf5WR\xcc\xe1P\xc3\x96\xf7\x14\xa14\xf8\xab\xca\x0c\x83\x14\xd9>\x00N\x02\xcc;\x1f\x0e\x99\xa2\xd8|\x8e\xfeb\xf2R\xaa\xa9Y\x86\xae\xe5\xfeG\x9f8\xb2\xc7h\x0e\x91\x13\x93\xa1GrV\xc5\x03'
        b'\x90\xe0\x14\xca\x02>Y`~\xef\xf9\xdb\x9bc\xc1\x84=\xe96S\xebdzi=\x92v\x8a\xa2<\x11\xc3|GU\x07\xd5"\xca+\xd1(\x16\x9c\xfd\xe96\xfe6\xe5\xa0\x97\xa9\xec\x80\xeeO\xfe\xc2\x15\xb36\x0f)'
        b'P*\xb0S\xa8\x95\xc7R7\xea\xa1\x87\xd2\xc0~\x03\x9e_C9\x9a\xa66MZ\xb3kh|\x0464\xf8\xa9(\xe87"\xd6\xcd}\xc0\x96\xda\xd7z\xabH0!\xb6\xb6\x80{=\xb3\x81\xfc\x9cf\x81\xc6Wb'
        b'U5\xde\x0c\x05<\xf6\xc9\xe8\x8f{\xa6\xac\x9b\xd6\x82Y\x8f\xe6t\xaa\xce\xfa\xcd\x9d\xd1\xd3\xe5m\xf2\x8f\xcc\xf3g\xd1\xea\x17\xd81Xj\xfa\x11\xe5\xf1\x12\xbd\x19)G.a8\xa0t\xef\xd5\x84\xcd3\xeb\xf77b'
        b'\xec\xe1\xb4\xb3\x1c\x8c6\xdb\xa8\xba\xc1\xa1s\xdf\xa1%\x94\r\x8c\xcd?]\x02\xc3\xd0\xf6R-\xdd2gx`\xce\xa7\x93n\x0f\xc9\x19\x97Z\xaa\xc5_O@\xbc\x8eWt\x7f\xcc\x7f{R\xc7\x95\xc6g\xbe\x17]\r'
        b'\r\x11\x1e/\xbfG\x18\xbf\xc9\xae\x9c\xbf\x80\x15\x1aU\x0e\xb9S\x88A-\x00z%\x87\xf3\xa5\xcb\x99\x9an\xe1\xf5\x03\xa6t\xe2\x84\xe0\x8a\x1b\xce\x87X\xa630#\x8a\xcd[\xc8\xdc\x96)\xd7\xb7\x9d\xad\x1f\x8aO\xe3'
        b"\t\xba.<\xd7\xb2L\x86\x13\xafo\xfc\xe8\xf9,su\xe7\xac\x05P~dT\x84hD}1*LG\x11\xcb\xe0\xf3\\]'\x17\xab\x02cUo\xd4\xef\xb7\x19\x8f\x98;Y\x02w;\x0c\xe4v\xa7\xc4!\xfc\xe8"
        b'f\xc6;\x9eC\xdd\x15.\xef\x03:\xbc\xaa/y\xe4q\xb3\x0e\x9f\x8d\xc1-\xf9s\xfa\x12\xdc\xe2X\r\xb8\x15L\xa2"\xda\x0b\xca\xb2]vi\x9c\x11y\xf1\xaf\'\xed\x19\xd3<\xde\x85,%\xbf\xee\xc1\xa3\xda\x89x'
        b"\x14\xf6@'\xe9\xd8\x9f<\xad,<\xe3\x0e\x07\xb5'\x02Yaf\xe5\xde\x07R\x16\xa2\xd9\x1aC\tW\xce\xb0\xf0\x9c\xf5\xda\xb7\xd6\xe3\xc8o\xd9\xfb\xd7\xcd\x93s\xa6\x8em \xc6\xbeg\xb2a\xb7<6J\xb4\x9ed"
        b'3\x94\xb3\xfb\x89\x91"\xd5t\x12\x12\x06\x02l\xd5$\x02,\xd9B\xb5\xb0\x9a\x96\xb1a\x1c\x91\x89b\xff\x9b]\xf4"\r4X\\JN\xb9q\x0bx\xe2\xc2\x94\xc3\xec\xe4c\xd4S\x7f\x1a\xb1\xddk&\x0fC\x15p'
        b'\xd7\xbej\xc7\x07J\x89{\\\xde]\xe6<P\xd3?\x03\x92$4\x0c\xae\xe0\xbf\\\xae\x9e\x98\xd2\xb1\xa3?S\x1b\xfb\x1f\xfc\xc1>\x16j$\x7f\x1c\xa1\xf4\xe8\xa37\x19\xc5B\xce\xd0y;\xf6\xc0\xf1\xfe!N\xb7\xec'
        b"\xf4\xa5\xad<\x14s\x97\x13\xffj\x1e\x91\xbd\xd2\xf6M\xbc\x87a\xed\xd5\xd3'?!\xb6qw\xfb\xff\x88\xc9\x93\x8eLs\xf9\x9b\xa0\x8d<3\xb8O\x0e\xd8\xb47/\xb0\xc2\x8a\x8dX\xbc\x1c\x0f\x063\x01\xbd\xa3\xa5g"
        b'\x92\n\xa1\xe3\xc1\x18\xfa\x0b\x8c\x98\x15\xdd\xbfE\xec\xa4\xc7(\x1erG\x8dp;\x91\xceH;0\x18\x0e\xea\x85\xd6\xbef^\x94\xfd\xd3*\xcf\xa9%8\xd0\xbb\xe5\xae\xb2\xb05\xe2\xc5\xc8\xe4T\xa7\xc1t\xaa\x16K\x12'
        b'\xa5\x0f\xe5\xc90\x98\xe2o\x075\x9f\xac\xb6\x99f\x83\x0e\xdd\x8e\xbeW\x9c\xce\t\xc2:}\x81.\x0e\xb2\x91-\xd5#\xb8\x90\x89\xabQ\xcd\x04\xf1]\x05V3bn\xfb?\xbbz\xf8],\xa5\xcf\xfev\x8b\x1f\xf0\x19'
        b'\x87\x9d\x07~}`\x81\x9d\x1b\xc3(3Q\x0c\xd8\x0f\x1d]j\x901K/Wf\x92\xe9>Z\xaa\xd1\x9f0\x87ny\xef\x1b\x04M\xed\x1781-\xf8\x81\xa0G\xfeo\xf5\xf3iv/M\xe9\n\xed/r\xf5Q'
        b'\xd3\x80\x91\xf7\xe1\x0e7\r\xfa\x90\\y\xd5\xf9\xc8b\\\xfb\x98\x85p\x1a1\xbe\xe0o\x1c\r\x08\xdf\xea\x0e\xc0\x12\xcc\x96\xb1\xbf\xbf\n\xc6B\xffG\x93\x95\xd0p\x88\x8aKu\x91\xdf\xd4/!K\xa7B!\xd7\n|'
        b'\xfa\xcexiZzlkj*i\x1e`[\x12\x91y\x99\x91\x99%\xc8\xeak\x9b\xa6x\x92\x1f\xd6t\xdc\x7f4\xda\x11\xac\x97\xae\xc8\x9f\xf9]e,\xb9\xc8v!\xb5\xc83\x9eU\x17\xbe_\xc3\xd3\x14\xf1R6['
        b'\xbfV\x91\xb8x\xeb1g!(\x9b\xc1\xe8\x08\xb8\xb8!F\xf3\x15\xdb\xac\x94\xfe\x91\x17\\\x87\x92\xb2\xd7\x8aw0\xff\xca"\x04\x8a\x10\\5\xce\xe0t\xf8\xac+\xe0.\x12\xb9\xcdb\x06\x12\x82T\xaf97~O\x1f'
        b'\xccg\x92\x1awj\xc4\xb9E\x08`>\x15b\xcdE!\xbd\x1ed+\r1\x89\xdf\x11XU\xac\x1a\xcaL\x00\x92*2\xf6^-\xcb\x81\x93:)-\xde\xf7@\xc7\x06n\xa4A\xbb\xb7\xd2\xf5\x93\xb8G\x08\x04_\xdd'
        b"\x0b9x\xfd[\x8d\xb7{_\xcb\x1e1C\x8b5\xae\xe1\xb9^\xab\xb0\x16\xdc\x92\xa7'\xce\xe4w*\xba\xaa\xe4\x1d\xac4'6;_\x8c\xc9S\xc7\xba\xd6\xd5!\x9e\x01g3\xe8\x1a\xd9\xea\xa6}\xcb[0\xfc\x11\xe9"
        b'}\xe1\x8d^\xa0\xbd0B\xefw\xf6\xd4\xd32\xda\xe7\xa2KD\xcf\xf8\xd7\xe0J}\xef\x85\xe0.\xb1\xca\x16\x87\xf1\x87\xcc\xc5\xa6+_:i`p{\x86;W\xae\xe0Id\xe3\n,7\xd9\xec\xf3:\xda\xafv\xb9'
        b'\x92\x9d\x1a\x13\xdb\xaf\xc8Fr\xdf\x0bh\xbdh;\xd1\x84%Z\xa70\xc9\xea\xcd\xfbFo\xf6\xf8\x92?\xec\x93\xa3\x8e\xcf\xe4\xea\x14\xb9 \x87$\x18\x91\x85m*-\x05x[m\x9fW\xb437\xad\xcej\x07t\xbc'
        b'\xe5\xc4\xdf\x00\x0f\xedQ**\x0f\x10}\xac\xe9T\x0cn \xda\xbe,\xcaS\xca\xdc>{\xa2\xe6HQ\xb57\xb7\xa7\x9a$\x00\x88\x81\nb\xff\x07\xc3\x16\xf5\xd0\xe1\xbd\xbf/\xe4\xb1\t\xd93\xb4\xe3\xd4\xfcfqB'
        b'U\xaf6\xc2\xfa\xb9q\xf7\x16\xf3\x0btF\x9e\xa0a:m]t\x92\xf8U~\xafF\xcfT\xc6\x1b*\xa6:\xc1\x1f1G\xf5\xd3W\x19L\x8e%L\x80\x83\xe7\xb1\xc1l\xe5\xe3\xf3\xeeJ\x1a\xf9\xdaa^K\x06\xa0'
        b"\xb4\xf8\xb9\x9b\xb2\xbcx\xc1\x8a\x02\xa4\x89T\xbb\x93\xca\x1a\xdd'\x1e\xca0\x19\xcc\x83*\x9d\x8b\xeb\xc9\x82\x1eZ[\xf0\xf4\xe4\xaa\x82\x86\x06\x10\x84\x1d\xe6\x15F\x15\xb94^l\xf27\x1eV\x9f~;\xe7{\x1f\x1d\xc1"
        b'\xbd\xc9\x1a\x19\xb9\xe8\xfdB\x07\x1f\xc2\x0b\x01V\xb8Yl\xb4N\x85::\x15>@\xba\x04@\t\xd4:`z\xbe%i[\xfd\xad\xca\xd0\xaa\xc6\xac\xbc\xc66\xe5p\x90n|\xbb\xea\x84h\xa6<\xd1\xd5\xc6;r\x7f'
        b'!\xa9X\xa1\xd3QT\xab~\xfa\xe6\xd4\xc2\\3\x11\x9dQqR\x91[D\x87-/\xcez\x12\xfc\xfa\xb4\xde\x00e\xb7B\xf46:\x98\x17\xc8d\x99\x8d#\x80\xc6\x0f\x83\x89\x1d\xa3\x8a\x16\x91\x81\xa3A\x188\xfe\xff'
        b'\xf8d\xbf\xc0\xcbN\xa9\x1f(\xe6[\xb6\xc3"\x13u(9x,\xf0\xb0G\x1c\x14\xe3\xf8\xa9V\x0b\xe7|\xf3R\xdf\x19:R8o4+\x8fq^\x90sO\xdc4yx\xa4\x99l\xef%|?\xf8\xc2x\x0fO'
        b'\x17\xe6\x06\xe5,*+\xa9sj\xedA\xf5i\xcb\xa8\xd0\xa7\x15\x12<\xd9\xd1\x9cl\x86B?\xb2.>\x86\xe1\x052\x002:\x06h\xf2o\xf4N,\x1b\xff\x0fF\xdew\xa8\xff\xf3\xd6\x99]\x17\xec\x99\xd2\x99GJ'
        b'[\xc1p\x1f\x02\x1f \xdd\x00\xdbS-\xe8\x15\x96%\xdc\x9e\x19&\xa59`n\x88\xfb\xebG\xa1\x12\xb9\xbd\x8f[\xa4te\x1e\xe8.\xe5\t\xe6\x8c\x03\xf7\xa4\xa3\xef\xb3\xc2{\xf1\\\xe9z1\x8d\x1b\x9dg*\x86i'
        b"\x10C\xdc3dL\xd1\xf3\x8bo\xd0ln\x19#\xf1I\xb4\x8dm\xb0\xa7\x96\xc5\x82w%kf\x06\xb9\x8b\x1f\xbbP\x9c5\xbd'\x0by\xd1\xc0\x97\xdcv*<\xf9oO\xea\xa2\x07iE\xae\xf4 \t\x03u\xe0e"
        b"h\xb7\xd8\xb0\xd0\xff\xd4P\xb2u\x1b\xf7=\x9eK\xe3\x1b'|_%\x84\xc8\xd4\xcd\xb8\x96\x8d]\xa3\xde\x91\xd1A>\xa1\x05\xfbfl\xc7W\xe9\x82\x84\xdb\xf5&{Wn\x07\x00\x99\xca:\x93\x92\x8d\xa1\xcbp)f"
        b'\xe4\xf3\xa0+\x02\xd2\x1f\xa2\x92\x8b;\xc9\xf4\xb1\xc7b^\r\xec\xd0iY\xd6\xe3j\xe7u\x05\xd2l\xaf\xff\xc8\xb7\xd1\x02=\xd9\xc2\xba\xf8\x1e\xe9\xb19SX\xae\xe7\x13\xd1\xd9\xecd\xce{\xea\x0c\x94\x15F}\xb2e'
        b'\x1a\xd3N\x93\x10\xc9\xd5Ip\x1a<\xa8\xb3Q\xaf\xacN\x1b\x95\xea\x8a:5~\xd0r/\x83\x96&\x99\xf2\xa3\x01\xa9\x17\xa0i\xa6\xe8"\xd6\x80\x14:\xb3\xd7F\x0c\xa1[\xe3\x95\xc6\xf1o\xf5\x16\x0br\xe1"l\x8b'
        b'\x00\x9d1\x85V5\xf7VZ\x11\x8a\r\x90\x82\xf6\xf3\xc9\xc0\xf2q)\xf1*\xcbH\x15\xcd\xca$h\xc2_\xb9\xbd|\xc1r\xc1\x92\x85\x9dGJy\x9f\x02!gM?N&Q}\xf9\xcc\xce\xa0\xc9\xff#\xb6id'
        b'\x8d\xfb\x07\x1f\x03jQ\xe5\x0c\xdeA\xbcZ\xc7s\x93\x90D\\\x9a\xb6up\x97XC\xca]6\xd2\x04M\xa6x\x02\xf6\xd1\xb8|\xfa\xd7$f|\x93Ag\xf6\xcd&t\xcc\x1a\xe0\xba\xb6\x0c+\xb4,k\xeb\xa2\xa6'
        b"\x0b\xf0\x10\xec\x7f\x1d\x0b{\x99\xf0\x929\x07\x14(\xb0\x80\xed\xd1\xc81\xfa\xd6\x11\xb6\xf8'c\x04\xb8\xd2pge\xef\xf3\xdcet\x9c0\xbfu:\xd1c\xffF\xa5\x18S\xe2\xef\xf3\xf8d\x11\xc1(Z\xc5\xee\xdb\xda"
        b'\xc1\xcc\xcb\xcc>Y\x0e\x004G\x1e\xa2\xb5\xd2H\xdd\xcb\xc9\xac\xe7\xb3\x14\x00\xf2\x88\\\x9b\x0585\xea]\xfd)\x13\xc3+\x8d\x1d\x13&\xcd\xdd@\x9d\x84\x0e\xd7\xd4\x1c\x83\xcb8\xc0y\xafz(\xf1\xfd*\xe7\xe3\x9d'
        b"N4\xc1hbr;\x86\xf0',\xbf\xee\x97\xd2!\xdd\xe0\\\xa3%1\xff\xb8\x9c3\xbb\xcc9\xb1\xc7?\x91\xa5$\xa5\x16\x7f\xe4\xcc{\x06%\xa0\x9aI#\xbb\xdf\x7f\x92\xfd\xa3\x81\x8d\xafe\xf4=\xd2Hw\x92\x98"
        b'E\xfe\x18DW\xfc\x0fB\xea\x0e\x8a3\x91V\\\xe6\x7f^\xcfFA\xc6D9\xb9:\xc7\xcf\xee\x1e\x1bS\xab\xdc\xd2\xa4}\xb5p\xd3dtb\xa87\x8c\xb7\xb1j\xc5cj5\x8a\x18\x84\x17Y/\x81yQ\xceR'
        b'\xfc\xa3\xc7\x80\xbak\x1f\xae\x8e\x1c\x97\xb9\xeac\xc9A\xdb\x0e\xe6\x10t\xec\xd9M\xfd\x94VB\t\x83\xffDOr~\x05\xdf\x01\xb1`\x8e\x9f\xb1\x9aU\xd8\xce@$g\xf2\xc1\r(\x97\xdfO\x81\x8c\xa2$\xc9%\x14'
        b'\xfb\n4C\xf9\x14\xd9\x10\xcb\xef\xc2\xd2 3<\x1f\xfb\xfd\x8f\x9d\xb1y#n\xf6\x14\x1aw\x11\xe4\x06\xff\xbd\x80\xea\x05\x0f\x92!d\x93y\xa9\xad\x18U!F\x07C\xf09I"\xbf\x03\xa3\x81\x97-\xee\x94\x93\xf9'
        b'\xbc\x90C\xa9\xcaA\x04%\x93\xb0no\x08\xf6\x16X\xfd\x1d\x9e\xaf\x8e\xdc\xfd\xe2\xeai\xde\xe5|\xcf\xf4\x9e\xbf\xf1\x96\xe7\xe5\x83c\x99\x16\xa1\x900 M V\xc3\xa0\xca\x8a{\x93\xe1J\x05ujG\xc2\x8b\x0b\xcf'
        b'\xdah.\x83\xea_\x10A\x19p\xc6k97Y}\x05"v\xf0t=w\x8c\x82\xb4\x03\xe5\x12I4K\xa6^^N[\x83\x99p\xf3\xa9\xfb\xbd\x07\xab%3>\xc9\xac\x0bp\x86\x05e\\\xdd\x821HB\x9fv'
        b'\x08J\x03u\xd2\xf0M\x8b\x0c\xbbL\xfd/\xad\x81M#\x02\xc1\xea\xe3\x1fj\xe9a\x0fO\xe2\x03\x17\xa9\xc0\xb8\xd8m\xcc\xa6F\xa0\xa8\xb33-\xe3\xe4\xa5\x83\xfakn\xa2%\x832\xc6MJO\x1ac\xc9\xccO\x14'
        b'\xa7\t\x8b\xe3\xab\x96\xa2#z\x85<~Q\xac\xcbn\xb5\xf8\xdc\xe7=95,\x9f~\x8a\xfa\xc3^\x8b\x12\r\xcc\xef\xb2\nl3\xa4\xc4{$\x1bT_\xcaW\x91-J\xa8X\xeeM\x08\x84\xb1\xc2y\xf8\xe9#\xfb'
        b'\xd7\xfdiAW\xaa8%h\xf3e\x17\xf3\xa5}\x94\xec"\x92\xe5\xac8\x98m\x1e\xff\x93v\xdf\xbaF\x84N\x1d\xb7\xf9C%\xef\x8dH\xc4\xd1yyew\xba\x9dr\xfe\x03\x0f@\x919\xe1\x01,\xc9z\xb0Z\x8d'
        b"h\xa9\xbe;\x88\x91\xb0\x8fi'\x84\xdb\x96\x0f\x06h]\xa0\xe6n\xe7\xf3\x93\xb2lQKg\x9a\xc3#\xcb1\xba\xb2\xf5B\xe1CX\x07\x88\xf2\xc12\x97\x9b3[L\xa7\x1c**\xee2\xe5=j\x12)}Ir"
        b'9\xba\xe2\xded\xa2YxU\xdfF\xbe]$\xb3\xe70\x1a\xa8,\xb2h\xd2\xc3P\xd5\x8c\x89\xd4\xc2\xc1,C*\xfa7VB\xf9c\x86 \x9dG\x8d\n\x08[\xab\xb8\xdc\x9f\x1e\xa2\xa2`\xaf\xab#\x85\xf4\xd7\xc7p'
        b'\xc3v\xf9p\xceM%\xc3XdT\xcf\xeb\xd7\xcf\x8d\xea\x0b\x8dL\xba\xe5^K* \xc2Y(\x13O\xda\xcb\xf2\x12\xf4>\xfdtQL:P\xfcK\x05\xd6\x89\xbf\xee\xba\x0e\x12\xc8\x9fC\xe0%\\\x8f\xdf\x80\xd5\\'
        b"*1\x1c\xe2\x0b\xd7\x1e\xe6X\x17\x88\xa0<_\x05N\x85\xc9'\x19\x04\xa9\xef\\\xd5F5\xd2\x0f}\xc8\xc3\x82!(\xc9\xfcD\xdcc\xbaK\xf4\x94\xc6U\xe3\xfcU\xce\r\xd1\x0b\xf8\xaf\x93\x87nE\x8dZrZ\xf0"
        b'\x91K$\xfb\xb9\xb9Md&\xda\xe1\xb1\x0b\x82\xaa6\xd9\xa1\xaa{L\xd8/\xed8\xcc\x85\xd8\xd4\x1c\x92\x0f\xc9\x95\xb7L|R\xecpx\xe1\x15NEH\xce\xee\xf9O\x9d\x90\xe3\x81J\xac\x04\xc3\xdb\xcb\x8f\x98\xe5\xf4'
        b'+[k^\x98bg`\xd3\xf3\xcfF\xfc\xba|!\xe05>\x13\xd2~\xfc\xd86(`\xbdO\x1d\xd8\r\x11\xc5\xd2\x8fR/*\xc6\x8c\xe0\x94\x89-\xe1\xfa)"\xdcwpd\xd6\x9e\xbc\xca\xce\x8c\xda\x1e\xe8uY'
        b"\xd9H*M\xd7z{\xf6\xce*\xce\x18\xa8<\xde\tyw\xe1z\xa8W\x87\xfa\xca\x00{7\xe5\x06[oa\x98\xea\xbb\xc0\xdf\x0c2\xec\x9e\x0b\xac\xe8s\xf2\x1a\x83\x92\xa1\xe6\x93\xa8\x1f$\xddPl\xc0'\xe4\xf1\x0e"
        b'\xf6\x88V]\xc8/\xd4\xbf\xae\x9b\xf5\xeb\x8e\x02\xd7\xccb\xf8\xe1\xafR\x152\x8embq!j\x1b\xdfZ\x99N\xa0\xbf\x95\xf3\x99Q\t\xe5\xb8w\xdf\xacR\xb4&\xae\xe2d\x06\xed\xd8d\x1aC\xba\x95&\xf0\x9d3'
        b'=\xfe\x05v\xda:#j\x1eS\xc1h,:\x8a\xe0\x93\x08)I5\xd1Fz\xeaQ\xcb\x7f\xf1Y\xb5E\xad\nsf\xa0\x94\x7f!\xaa|\x1bL\xb6F\x7f\xcb\x8a\xc8tA\xa2\x8d\xfdB\xcc\x9f\xd6\x83\xd2\xact\xc3'
        b"\xbck\xd1\xec\x94\x1a4\xe9CMQ2\x89D?\x0fW9U\xd3RE\xd5r\xbdaJ\xe2hVN\xb5\xab\xd1\xa0'6/{\xdb\x01h\x08\xd4,\xe8*A4\x00<!\x91\x9e\xc1\x93\x88\x0b\xa2>\xab\xbf\xe5e"
        b'S\xdc\xf7\x86\x1e2\x0cl\xe8G\x08K\xea\x1bs\xcdF\xfa=-\x8e\xebi\xb0i!\xb1\x1cRB\xac\x11.e\xd3\xd3)\xc1\xe1OnItv,\xaf\x87N\xe5&\x97\xbe\xd6{m\xf7|\x1b\xe4\xa1\xe1\xb2\x15\xe7'
        b'\x80\xa2\x93 \xe3R\xc3\x94a\xffA\x1e\xa5\x1d\xbe\xa5\xd0z\x08\x92%\xfcT\xdd\xf1\xb9J\x9a\xdc\x85\xfa\x1bL\xdc\xde\xbb)\xd8\xc0!\xf5\xd1\x82\xccO\xa4\xaaIT|\xd4H\xdaL\x7f\xffw\xe8\xd9\xc2\xa4\xf8\xc0t'
        b'\xb2\xd6p\xc3s\xe7|\x00\x11\xb7\n\x7f#\xd0\xa7\x89\xfe\xf1\x82@\xdb\xbe\x07a\xe9\xcc\xe1\xe0\xe9\x8c\xc3\x05\xb7\x1c\\\xc3N\xe6\xcc\xff\x0fw\x8aH@\xack\xe4\xb6\xf3\xa4\x81\xe8\xba\x11sf\x14\xda\x0c\xab\x03\xc6\xfd'
        b"\xdaP\xbd\xf0\xa7SoM\xd7\x16w\x95%\xb7\xeb\x86r[\x84\xec+t\x05\xb8\xce<|\x94WL\xd8#m\xbf\xd2\x93\xa6\xb3\xef\xaa\xadA<\xe3k\x87$\x8a@\xbe\xcf\x8d\xf7&\xd9\xb2\xf8\xe5\xac\xe5Ph'e"
        b'\xf8\xb3>\x7f+\x05\xb2\xc5\xc3\xd9\x92t\xe4\x14\xf0[\xaap\xa3\x8f\x0e\xe0\x85`a\xac\x83\xbc\xdd\x00\x8d*M,\xcd\xee\xbe\xed\xde;\xac\xad\xdcG\x88\xa7S\xbc\xb0\xcdS\x1fV\xb1\xb2\xdd\xa4\xa0\x1d\xd0\x16\xc9w\xf1'
        b'[\x0f v\xee\xdc h\x9aJ\x8d\x99\xe1~\xa6\x8cM\xf8\x1c\x05\xc2\x1e\x05\xae\xf98zf\x94\xbc\xc6\xa9\x00W\xb6\xff\x10\xefFA\xf0\xcd\xbei\x04\rN\xbd7]\xddT\x7f\x1aT\x98\xa9e\xf9\x93X2\xc0\xfa'
        b"o\xc9P\xdd\x9f\xc3zF\xe6\xca{\xc3\x06\x02\x18\xf1\x13\xe7\x85\xe4\x83\xa9\xb6:\x8e\xad\x94\xe5r\xbf'\xc8#\xe4\x8d\xa0\x0c6;\x84\x83\xde\xb3y\xc8xC\xda\x11=_\xcd\x06\x99`'\xa6#U\xd8\xdf\x0c\xc0c"
        b'\x1b8\xa8\xa4\x1f\x8d\x88]m\xfc\xbe\x87\xf4\x81.\x942e\x0b\x87\xfbX_\x057\xb4\x9c(\xe6\xa8\\\xb2\xf4\xf7s^\xe5Psi\xdc\xdb@=\n\xf8w\xaf8]\xcck6\x0b\x97\xc4\nK\xcf\xa6\x03\x1a\xee\xf8'
        b'j\xc4\x89z\x05\x04.\xb2%\x91\xde\xff\xacy\x08\xffjW\xdd\xdf\n\xf9\xeb\xe3`\xf4\xac\xa3\x97gz:\xb2\xb5\xb3\x05\x80\xe1\x8d]MM.\xbf\x98\xa9\xaa\xfeG\x8a\xcb!\x9e\xad!\x1a7\xc7y\xee\xef\xe4\x1b\xbf'
        b'\x9a{\xc8\xff\x84FW\xca4OYU\xfc\xc6\xb4\x8d\x841\x99+\xdd\xe9\xa2\xcdu\xd8O\xf6$!\xc1\xe3\xce\xf1M32b\xb6f\xe6\xb5\xbf\xe4\x89\xec\xa7\xb3E\xd4\xb5\xe7K\x97\x8a\x96\xe6\xbcdwY\x80\xe6\x88'
        b"\x0e\x82\xdf\xcb\xe7\x90a9c56\x82\x1e\x12\xe2\xd0\xbfG\xe5\x9d\xbe\xfaa\xb4)\tS\x982\xa6Ct\xb0\x1a9y Y\x9a\xa8\x19\x82:\x04\xfd\xdb\x18\xb43\xea\xf2\xaeO\xebY\xa4\x01\xb8'#\xe9n\xf5\xdd"
        b'x\xba\xe2\xf3r\xa0MD8\x04\xcf\x89\x86\xc5\xfb\xef\xb2\xdc|\xaf\xa8\x15a"\xa650\xac\xb2)\x9a\x06\xd0\xf1+\x03 \xf8\x93\xbf\x90\xb6T\x00Od\x19\x08\x90\xfe\xa3\xd9e*f+\x11\x07Op\xe6\xe4\xe2\xb6'
        b'\x06\xceW\x1a\xb6\x82\x93,\xd1i\xcb\re\xe3\x9eN\rb|\xd8\x85N\xb9+\xb7\xaa\xbe8*\x9c{\xe4[\xc3\xc0\xcfk\x92\x02\x12eS\xdf\x99\xc3uCi\xe0\xbc7qgj\xfa\x1b\x84\xe6\x1a\xf4W\x07Zj'
        b"J,\xc9\xbeb\x13\xfe\xc6}L\xb8\xff\xe7'n\xc7\xc22\xf3l\x108\xb0K\xd0p|(C_\xca\x94+\x10ux\xbc\xd3\x0b\xbc\xef\xe7LB1\xd7\xda\xfdD\xd4\x01a\xe0\x05\xcf4\xa2\n\xbe\x7f\xd6vx\x1a"
        b'8(\xf5\xb8}\xd9\x11QU\xd9\xc8\x10\x03\xec\xf9Q\xd5(\xbf\x90\x03Mb#\\`\x17,\xcb\xd1\xa3\xce\xa0\xac\xc4dv\x0c3\xdb\x92\x9d\xde\x04\x06\x9a\x10)\x7f\xf88xJ\xfe\xbb\xe1%\xea>\xc3m\xc5\xd2\xa7'
        b'\xbb#<\xa9ak.\xcd\x92\xba}\x08\xa8\xd5A\xe8H\xa8\x86\x07b\xff\x96\x0e\xe3\xbf\xf9\x8c\xd9\n\xc7v\xc6\x186\xfe\xf3DF\xf8\x8d\nDM\xbc\x15\xd1o\x0b\x8c\x1d\x1f1\xe9\x85;\xb1N\xee\x8b\xe41T\x8f'
        b'v\x94\x08\x7fX\xda~Kb\x8f\x0eE\xb74\x9c\x84\xe3\x0e*mi\xc4\xa1\x01\x14\xa2u\x16iZ\xfeq\xc8\x89\xe2\x9c3\x95\x85\x0c\xd50\x87\x81K4\x8c\xea=g L\x87\x8fl\xbcP\xec\xdd\xf8;\xbfX\x89'
        b'\x02x\xca\xb4\xf3\xc7\x0b\x1f\x86\x80V?#\x9aP\xc4KL\xa7\xb4\x87r\x1b;H\x17`v\xef\xcb2\xc8c-\x1c\xce\xc9\xd2s\xca\xc0\x80\xf1d\x95\x97\xd4\xe3\xfb\xb1N\x8fl\x86\x83,=\xdc\n\xa9\x08\x8e\x07\xc7'
        b"\x00\x05y\x91\xdf\xcc\x8cr\xa3\xa4%'\xae\xd1\xcf\xe2\xcc\xedX#ZD{\x00\xed'\xd3G\xdf\rnc\x02p\x89\x0fQ\x02<k\xaauQ\xb1\x06\xde\xd9<A\xb3\xd2\x03G\x98\xfa7\xba\xd9\x17\xb1\x9e\xf0Vg"
        b'\nN\xc9\xc6\xba\x03\x96\x84\xaec\xbb\xa1\x11\xc1xC\xebR\x19\x9f{Fs\x96\x1eD\xfe\xb4/\x909\x8db.\n\xdd\xb8)9\xce\xb3\x9b{w\x85\xd3\x81\xcf\x86\xd7\xb1rw\x9c\xf2\t\x96\x14\xf5*\x11\xd5F.'
        b'.E\xc0:\x13\xfd\x02x\x98@\xfe\x82\xa9\xc9\x90\xcf\xf1\xc9\xe5\x9f\xfe\x8b\x9b"\x1c5j&\xa2\xf0&x\xbf\'&\xe6\xfb\xcdL\xe4\x9d\xe1\xed\x88\x11t\xb1\x19\xff6G\x05\r\x10\xcb\x83\x9cy\x80\x8cb\x9f\x83\xce'
        b'\x1cp[\xc5\xd1h\xc4Q\x06\xe4\x0f\x00\xd0\xa6(\xbf\x0e:5\xfeh\x11\xb7\xe56\xa0\x1d?\xfaOm\x84\xd9\xe5\x9dZ\x90\xa2\xe2\xc6\x7fx%\xa6\x83\x11.\x05U\\R\xe3\x1e\xe6\xee\xa5<\x986k*\xdb\xa3\xca'
        b'\xa9\xd8\xea\xaf&\xa4gz\xe5\xd8q\xd2\\\xe8\x19\x00\x7fRE\xf7\xb66?\x93\x01\xe6=@\xc7\xfez\xbe\xd8)\x1eHVg\xed)\x15\xa0\xc3\xce\x84,=\x86)\xd7"\xe1Y\xcb_z|\xde\x1fkR\xa4k\\'
        b'\x91\xdaiA\xf8%\x17&7\xcd\x0c\xb1\xbf"B\x10\xc5\xb2\x0b\xa2Y\x17\xfe5\xaf\xf5\x9a\xd8\xfd5\x88\xc8\xa8\n^\x1a\x8fJ\xfa\xbaS\x89\xeb\xc8(\x89\xcb)\xc0\xdd\x16\x7f\xcc[\x8fIc\xa9\xb2\xaa\x0b\xbb\x0cu'
        b"\x8b\x81\\\x18\xfa`\xa7H\xca@Q\xab\x14>\xcf\xce\x0b\xe4\\\xb4#\x9b\xf8\xb3\x0f^\xe7V\x11\xd0'\xac1]\x83\x02w\x1d\x91M\xb2\x7f\x81\x8f\x94\xa4\x8d$\xb8\x92h\xa3$*\xa8\x92\xb8\x07\x97\x17Zg/T"
        b'\xcb\xc3\xa3\xf4 \x1d\x01l\xa8\x9a\xd3\x84\xdf\x81;\xba&\xe6\xb4X\xe9\x07\x107\xa2kY\xb6\x93\x8b\xd4o\xa0\xd80w:\x9f^\x91\xaf\xe0*\x81\xedp\xb2\xc7\\=\xcb\xa4\x9a\x13M\xeb\xec\xcc\xe9\x8aX\x81@*'
        b'\x7f\xb1g\x96$a\x92\x02Z32\x9e\x01\xa9UPO!\x1f\xd2o93\x81\xba\x1e\xa7\xcf0\x1d`\xb1\x1fM[\x02Ri\x18w\x80.\xdb-\x88d9e \x9e9$\x0f&\x7f\xb8\xc4\n\xc5\xcfH^F\xb2'
        b'`\xafB\xb2\xaf\xa1\x14\xef8\xc5nw\x96\xe0\x96\xbb"G\x1b\xf9\xe0~h\xd5V\x033\x00\x1eE\x1c\x13og\xb7\t0\x08\xcb\xa0\xb2$\xf8,7\x13\x9d\xbdb\xcf\xbeg\xb4\x83H\xe4(O+I\xa2i\x8d\xf9'
        b'\xff\xeey\x90\xe1uL4\x87\xf6\xe3\x9a\x01\xae\x06\x95],-\x91&\xb3x\xc7\x9e\xb7%\xbe\xdc\x1eM^\xda\xf9-\x85#\x82w\xec~\x07NX\x12\x9a\xb4\x9b\x10\xcc\xfe\x90+\x11@\xf3nC\xf8\x17\xc2\x99\xe0\xc8'
        b'R\x03N\x0c\x87\xd0\x03\xe4\xfc\x13R\xcd\x05Cz\x8d@|b\x0f\x9a\xd6\xf8\xfb2\x14\xe2R\xca\xd2\x0f1E\x1f\x80v\xf7z\xbd\x16\xdc\x077a\x8d\xe6\x96\x9dd2\xb3\x87c\xd0T\x89|\xff69\x19\x942\xa7'
        b'a\xe9\xab\xd9\xb9.M#\x99\xc3\x97$\xb4\xcdq\xc53#\x93\x08\xc7\x99\x18^\xd0\x13\t;\xbbm\xcf\x02\xbb\xc1^\x92J\xed*\xfc\xc8\xc9\xfe\xd6r\xc8g/`\x82\x87t4n\xc1\x92\xaex\x8d\x8f\xf9\xde+4'
        b'I\xdf\x14W<].\xa6B\xb8\x9fa\xd6b\xae\xb3\xbb\x1da?\xd8\xfcW\xcd\x04\xd1Q\x9c\xe9\xfdf4\x1a\xce\xd7D9\xabu\x87\xee\xa8\x12e\xf8\x8d4\xdd\xa3\xfac(f\xbc\x1a\x14\xd5\xa8\x95\xad\x19\xafcW'
        b'w\x1b\x8c\x13\x04\xc3\x89\x90\xfa\x138a\xc4\xc5\xe5\x93\x85\\\xd6p\xa7\xebL\x11\xf2`\xd0\xea%Y7\xc0\x8b\xccm\x06\xea\xa8o(\x82\x81\x06\x8a\xd4\xa0VT@\x0b\xcb\xe2\xe0\xf0\xb5\xdd\xa4\x80\x90\x83\x828\r\x03'
        b'\xe9\xcf\xa5)!\x15\x1ew\x82do\x05\xa5\xab\x9f\xe7\xba"\x9dg\xd5cx\xd3\xe3^BG\xc7\xe8\x8c\x89\x9d\xbeY\xc4\xd1D\xb2\x91\x8b\x90\xfa\x87\xd5\x8e\x9a+\x8b\xec\xbb\x18V\xcd\xca\x8d\x8b\xad\xf9j\x99bZ['
        b'x\x89\xcd\x1e \xe5\xb6\x92\xf0s_\x83\r\x10^\x95\xaa\xde\xfd\xfc*\xd2\xc3%\xcaZ\x1c\xf3\xe4\x03\x84.\xc3&\xad\xcd\xe3\xbdz\xbe\xe9\xa9\xa2\xd7 \xbd}\x91\xfc!k~\xe8\\\xda^\xcc\xb7\xd4t\xd7\xfanp'
        b'\xcf\xe8\xb2\xafn\x0f\x9e]\x97\xf9@\x82\x1e\xd3\x9b\x85\xa3:5r\xd8c\xfa\xb1\x92&v\xd9\xce\xe73\xd9\xf2\xdc\xd5\xde\xe8\xf3\x0c$B\xd7\x14\xb5>\xfd\xde\xbc3T\xee^\x96Tr}\xe1\xd0H\xeb(i:\xe0'
        b"\x92'{jO\xc8L\xdd{\xcec\xf1w\x84R\xc3om\xb5+U<\x1d\xa0\xa1p\xc2b\xa6\x8f3\x9d\xda\xad\n4kG K=\xe5\x9e\xd3\xc9=\xc5\x9f\t\xa2|\x1ea\x8at\x05\x8461\xb0\xb0e\xa5\xee"
        b'\xe7F\xac\xfa\xd6RM-E\xdd\xea0+\xd4l\xe3\x07\xb6d.4=k" \xe5\xfc\xee\xaf~\xd5*A\x94%\xff\xfcI\xbe\xd4\x9ea0#5\xf0\xfe\x1b"\x17\xa9s\x93\x90<*\xbb\xd1l\xf9\xa1\x0e\xee\x01'
        b'i\xdc\xb1#\xfb\xb1\xf3\xe4\xa0\x82ot\x9c\xa9i\x8b)%V\xe2\x08\xfe\xca\xfd\xbd\xd5t\xdb\x80$\xbb\x95\xbb{\xdf\x95\x13\x89*\xa2\xc9\xc0\x1d\xceNy\x9e\xd7\x12\x1bK\x88\xba\xf6f\x9b\x8fY\x1du"Q\r\n'
        b'\xf6\xfd\xef#y$\xac\x84\xbd/kn\x00\xe0e\x8c\x80\xac\x95\x96\xc3\xbas|\xc8\x07\x0c5\xd5\xe4l\x9b-w\xce\xdc\xb0\x1co_p\xc9;\xb4Z\x14\xc4\xfcM\x86\xdd\xb4\xc0\xe8\x7f\xb1c:\x17\xd0r[cD'
        b'\xc2\x8a\x13\xe6Z\x8b\xa6\x1f\x1ex\x8d\xf9\x8d\xfa\x15JqSb\xb9\x1f\x91Td\xf2\xfd\xda\xfcb\xf3[q\xb3-\r\x92`E\xc6\xae\xd4\xb0pp\xe4\x1f1\xfb\xd8p:fa3\x9e%!\xca\xe5\xe7\xdc\x7f\x05\xdc'
        b"HS\x1cZ\xaf<7\xfe\xd7[\xa0X\x93p\xad-\x1a`\xcf%\x10\xe2p\xe3eG\x85i\xb4l\xfa\xcc)\x8e\x93}\xc9\x94C\xdd\xdaS\x01\xcb\x06\x93\xa9\xa4[0!\xffo\t\x9d\xbai\x9dW\x98'\x12\x96\xbc"
        b'?L[\x7fl\xe6\xc0^#\xf2\xd37<\xd1YT~Y\x89\xcf\x9b4\xf6\x8d\xcf\t\xed,/\xaf\x95\x945\xf1M\xdf\xc7L\x01}\xd5\xe3,<\x90#R\x9fJ\xdd\x9e\x83\xbb}\xdd~\xd8]\xd0\xedV"\xdd\xdd'
        b'\xe6(j\x8e\x7f\xa0\x18g\xb7\r<b\x1e\xec~\xcd<B\x83j\x9d_~\xfd\x0c\xce\xa7a5oB\x08yjf\xb6Y\xca\xe9\x84O\xc1\xa1\n\xb5\xec9\xb4V)s\xd5\x08\xceE\x89\xe0\x14\x8d\x87\xf3i\xf5<'
        b'\xeb\x81{\x9d\x16\x1eh\xecl\x84\x8c\xe4j^\xd9\xc9\xbe\xa1\xd7\x93z\x12{\x1e\n%&c\xbf;\xd4t\n-$)\x06f\x8eC\xe7\xd0~\xb6\xc8(\xcf\x11x\x8b\xc0/ouQK\xa0\xf1\xd8\x87l\xd431'
        b'\xa4\x80X\x84\xc9\xf7\xdb\xa2\x1e\x1c6H\xaf\x8c\xe5\r\xc3\xd9O\xb5\xca\xa1\xd6\x14\xb8\xc4\x9f\x97%\xbd\xec\xac\xa4\xde\xe8\x9f\xdc\xc1u7,Bv\xb5X,\xb6\xb7L\x9c\x04\xed\x88\x9a\xc1\xa1\x03\x91a4\xa5\xa2\xf7~'
        b'Gk\x94\x8e\x90-\xd4\x9a\xe8\xea-\xc5\x8c\x96\xe6\xf0\xea\x9f\xd5\x14\x82\xcb\x87\xf98T\xaa\xb7\x9d\xa9O\x00:\x8d\xc8\xde\x850M~F\xb6=\xc1\xc4\x13O$\x1f\xd1*\x02\xb2\xfcu\x0fls\x8b\xee\xa8\xd5\xe1\xe9'
        b'b\xf1\xbb\x18\x8c\xa0K\xad\x84!\xadW\x9f\xaf"C\xb3\xd8gg\xd4\xad\x89r\xa9\xe6\xd4>\x99j\x9d\x89OmZ\xae\x15\xb0\x01\xb3f\xe4\x06\xe1S&\xf5\x85\xb1t\xf3T\xbbh\x0e\xaap\x8a\xb1]_i\x1a\x9a'
        b'\xae\xa9,\x876P\x87}e@\x80r\x00\xe70\xaa\x0e\xe4\xf1\x81q\x82\xa1\xf1\xec\xdf\xe5\xd9o\x10~\xbb\xb6\x16\xe1QK\x14\xbd\x1d\x8cp\xe6$\x81\x9c\x83G5>\xa5\xdf\xb5\x19\xc3\x05\xb0X\x89\x07\xf2\x97\x7f\xbd'
        b"\xa0m\xabjZ!\x1f\x1c\x00E\xa73\xa6'*\x05*\xef\xb3z\x96\xe4\x87T\x03\x9ep\xb3\x04O\x9fF\xf7Wy\xa1d\xe0\x0f\xdbx\xea*@\x0cPH\x82!\x7fp\xbc\xdc\xf1J c\x01\xb2M\x03\xe6\xdcj"
        b'\xd4#\xa6\xd5\xe9\xb9\xc6y1\x84l\xa8\xfb\xc12\x1ds\xbb\xbd\xc1\xe1\xb3y\xf8s\x8f\xca\x81T\x1f\xc8\xa0\x1f%p\xcd\xeb6\xe5\xb3\xdd\xd2\x17`\xf4\xc4\xd22\\\xc9\x03\xec}\xadSdI\x87A\x9aV\xd4SV'
        b'\xe5\xa2\x95v\xa9\x86-\xb7(\xfe\r0g~\xf2\x19\xe8\x10\xa6/qykX\xc1\xd4H\xc1\xf1I\xb9\xe6\xbf\x9a\x12\x89\xfc\x1a<}\xf3\xff\xe5V\xaag\x99v\x86as1\xfd\x06$(\xe5qE\xff\xdemm\x05'
        b'\xc6\x05Q?L\x03\xba\x1e\nX4U\x90\xbaD\xe5\x14\xdd^\xb5\x1b\xa3^i\x96\xb1\x82r\x8c\xceY\xb0(P\xe0\x8a\x11?\xd5\xd9\xa8\xd2\xeb\xdc\x01V\xc5\xad\x05\x08\xe7\xa8\x8f3[Z)\xc7\x89\xac\x14\x91^u'
        b'\xf0`\x06\x00\xe5\xfa\x90\xa3e\xd7\xbe\x00\x84\xe5\x024\xd7\x9f\x1f\xc3]0\xf2\xc5\x97\x8dCt\xdf~\xe7/\xcb/%0\x85K\xc0\x9ey\x96\xdd5\xe55\x8cI\xb0\xe3\xa9\x81\x05~\x93[\x90U\xc8f,\x05\xca\xa7'
        b"\xab+x2\x9eA\xb2P\xfa\x15'[,\x85\x1e\x8c.p\xca~\xae\xce3k\x06\xc3\xbd\xfexmPL~x\x8b\x08\x8b\xc1@U0T\xdeT\x08\xdb]\xc3\xfe\x05\x82N\x95s\xc6i\x96\x90G\xa0\xb0\xad\xdf\x13"
        b'B\xa9#q\xc6N$\x92T\x9e\xf2\xcd6=\xff\x87{\xafn\x91\x8a?\xadJ\x8cX\xba\x07\xbd\x02\xb4,c\xfb~\xaa\x15\xacA\xb9\xf8\x94F\x96\xfd\x8c\xb8#\xdeb\x87\xed\xf0\x80\xb1\xd4\xba\xb4\xe3\xb0v\xe1Ek'
        b'\x02\xe4u9\xad\x9d\xa9\xc9\x84\xb1\xcb\x99L\x98m\xf8\xa7%\xe8\x14)&\x91G\xda\x13c\xb5f\xf5_f\x064\xbb\xd4\xa8\xca7\xf5\xb4\xcd\x1a\xd6\xf1#\xca\x91\xf3\xc3\xefx2\xad\xa5m\'\x9d\xe5nY"\xf3!'
        b' SU\xea\xa4\xaf+b\xf8\xacO\x17\xf8\xd1@0\xcb\x02\x9aP\n\xfc\xaa^\xe3\x92\xb1\x94\xe6\xdeN\xe9\xa0\xdaBw{\xd0\xb1\xc0\xb5\xc8#\xee!0\xda\xf6LU\xafX\x07\n\xa5(\x1b\x0c\xd2\x8f\x93\xf2\x96\xa6'
        b'\x93\xd5)\x8cD\x8aOk\xd4\x8f\x1e \xf1\xd18\xbc`\xc1\xdc\x8b\x85GdyUr\xcd\x99\x0f\xfb\xa4O\xa7\xc3\xd9\xf5\xb2\xda\xad^b\x8bHuj\x16\x87\x1dt\x8c\xe6\\G63\x19Q\xc8\x12v7\x193w'
        b'0>\x87N\xd3\xd7\x9a\xe3\xc9O\x91\xf7\xb7\xc1\x15h\\B\xbb\xd3!\xb2\xfe\xaa\t\xec\xb7a\xe3\x98]\x01\xc3\xb8}\x8c\\\xabo\x845g\xf3\x96\x08\xba\x9fNb\x841\xc8u\x9b\xc57\xf2\xab\x94\xbc\x8f\xa8\xc4E'
        b'\xbd\xed$\xbb\x9a,\xe64\xea+\xae\xe6\x7f\x98<q\\\xe4\xfb\xa2\xa4\xd1\xe2\xa0\xf6~\xd2\xad^\xbf\xd1\x9e\x1c\x80\nxT\t|\x8f\xf6\xaet*\xde\xda\r\x9fM\x96\xcd\x1f2&\x89\x18F\xbf\r\xf4\x16U\x83\x06'
        b'@\xbd\x97\x80s\x89\xbe\xb2\x11\x8cY\x1b\xa6,\xe0\xfe\xc4&J~F\xf1\x93\x08\xf3\x85\xdb\x06\xce\x97\xc3\x86\xb5\xe3\xb0B\xaf\x8f\x85\x14\x88\xee9\x17\x12s;j\x90\xc1\x876\xe2\x93\xea\x1dn\x8b\x03\x0c{\xaa\xe8}'
        b'\xe4;\xa1\x07RG\x8ee\xd0\xdf2>=\xf2m4 \xa8\xd4kh\xff\x82a\x7fd\xfd\x11\xe96\xa5{\xe6]R\xdc\xf1o\x83\xfa\xfb(\x97\xeep\xfbf\x86z,\x17\xc0\xaa\xeax"\x12f\xe8\x84DY&\xa4'
        b'e\x7f(\x8f\x8d\x86\x08,\xea\xdbb\xc53\x1cg\xabWVb\x1eK\xfffJTB\xd8\xaa\xe3\xfa\xc0\xcei\xa2\xb4\xa8\xecsk\xceX\x0f<T\xdeHG\x8c\x0e\x9d\xbe\x8a\xb78\xd5\xf89\x9aS\xe9\xc0\xec_\xed'
        b'\x07\xdc*\xc3\xe8T\xbd\x96/\x03\x9b\xca\x95\xee@\x15\xe5\xddu!\xe8v\x12u\xd5\xa7\xbd*\xa6\xc0\x02x\xa6\x82Tjlt-\xe4\xef\x1b\x08\xaf\xc9\xfc\xf3\xc3qo-\xe5\xbe\xcc#&\x17\xd7\xf9\xf6\x99Wb7'
        b'D\x079\xb7\xe1f\xf4x#\xa5"\xd2\x93e\xf3\xde\xeb\xe0\x05\xfe*}\xd4\xb4u;u\xccde\x0f\xb3Pb\xd1\xc2\x06\x9cV\xe9\xc8\x0e\xcc\xc9\x8a/\x11\x13\xa6\xdb\xbfv\xc4\x83\x81\xb4\xce\x84\xb3nmc\xbd)'
        b'bO\xcb\xce\xf6\xd4=\xcche\xa79a\x1a\x02\xa6\xfd\xea\xbb\xc9|\x98A"!9\x80\xd1\x1a\x0frw\x9d\xd5\xdc\xbb%\x0fg\x96\xeeM\xfcU\xe9\x97\x1d\xcf\x1c\x1f\xa2\x80\xa3\xff\xd5\xb0\x03\xa3\xd5\xce\xc7@F\xa3'
        b'$\xd0\x98M\x97W\xee\x17\x98\xf7\x90=\x84\x15\xd0\xda\x88V\xaf\x038\x91<\xb4\x05Iq1\x8e]\x98\xb2\xa2\x1e\xc7\x04\x1a\x96\xb9AQ\xddF\x8d( \xceR\x88H\xf3\x0b\xed\x00BB\x93\xfa\xabns"\xfb\x1f'
        b'ey<rK\xf2hM\xdc\x93\xfdN\x9eo\x89\x82\x13\x98 \x90\x07\x90~\x83M\xb7y\x9c\x06\xd0\xa2\xf0\xd6W\xc3\xc7gzP\xc7\x97_^\x93\xf9\xf9UN\xf8,\x97\x8e\x07R\x81\xfe\x000\x06T\x9e\xb1\xe7\x0e'
        b"\x9e\xb7}t\x0eNA\xef\xb0\x13\x1cbb.C\x88\x1b\x8f&7\xcc\x85\xf8\x8f\x16hp\x1c\xac\xe0\xa0\xed\x0eQG\x19\xe0\x90\xee\xcd\xb4\xf1\xe3=\xdb\xd4\xa0\xb4\xe0$\xa5\xf3\xe3\x98\xd5\xc5\xb2\xcb\xe5'Icp\xc0"
        b",Ub\x86s \xf6Ka0Nz\x8d\t\xd1\x86v\x92\xc94\xfd\x0c.\xf0GZ\xad'j\xa3\x96\x00\xbd\x08\x1a\xd2.\xe7\n\x8a_\xfb+_\xd38\xcbt\x84\x84.\xc6\xf6*\xa5\xf7\\\x98\xc9F\x1a\xbaC9"
        b'x\xd5E\xffP\xfa\xd6y\x85Af\xfdP\xc1\xbf\x0b\xbe\xc03\xce[\xdcb\nw\xe1LhJ\xaee\xe7\xc5jv\x1b\x86Y\xfd\xe6\x0b\x1e|\xb1JE\x8d\xf8\xf9`\xa9\x1e\x8c\x1d&\xe6\x07/\x1cZX}\x86E'
        b']\x0b\x8c\x1f\xc59\xc9\x18\xf0s\xa7$\xe1\xb31\xa5\x04;gD\xf4\x9c-\xd2\xa9W\xe7\x93\xae\x11\x00{\xb4\xe4\xf3\x8e"1\x82\xa6\x93\xa13t+\xc7\x1a1\x82\xd7\xca\xcbj\xd6I_-\x1eX\xa9S\xf8\xfbU'
        b"\xd3\x8b\xa6\x9f}\xf1v\xe7\xaa\xc7\x00\x1e*e1}s\x05\x18\xb2M\xfe\xd6\x87{\x8f\x8bA\xee\xeb\x9a\xf3u0\x89O )\x15\xa8\xb5\xad\x89\x8fA\x94\xae'\xd2TO\x8e<\xf9\xfa\xdc\xf7\xc0\x83m\xd9\xb0Y\xde"
        b'Rx9V%v\xee:7\x8c@\x8f\xa8\xcfXp\xc9\xe8\xcc\xdc\x0c\x0cf3?\x91\x07k\xa4\xc4\x89eY\xf2?\xdf\xfaf\xe1\x0b=W)\xbbZ\x8a\x9b\xb2\xff\x92\tf%\x95R\xdc[T\xc6\xc5.\x07\xb0\xd5'
        b'\xed\xb6\xf6\x01\xc9\xf5T"\xa6{=\xaa~z)H\xf6AE=w\xad\xba!o\x89*<\x14&J\xf1=FNz\x8bZ\x1c\xcfg\x94\xc8\n\xb1yu\xc6\xe1g\xc4\xd1mG{6\x96\ne\xed\xfb\xfaf\xd9'
        b"v#I\xe37V\xb8s\x93\x04\xae \xddc\x97\xdd\x8e\xd4\xdc \x89{\x15\x90C\x17\x02~\xd8h\x8c\x9cQ\xfb\x07q\xceb\x17\x90?m;\xec\x8a\xa0\xe5'\xdb\xfe\xb2\xe0~{\x15\xd04\x9e\xaf\x05\xcd\x05\xe0\x9a"
        b'>I\x97\x86{8<%eM\x1c\xf9\x91t\xe95C\x11\xacMZ\xbb\x8e\xa7\x88\xba\x9c\xc5\xf1\x90.\x1eO,\xbb@IL@\x84\xa7\xb5&\x17\x0fSX8\x0e\xb7\x81T\x05\xba\xda\xa3w"\x15\xcc\xe0\x83\xb9\x19'
        b'\xa1\xd9\xb1Y\xfa\xadal\xf3}\x8a(\xd0\xd1v\xaaZ0 \x95l\xeci"\xf26\x8e\xb9\x81\x01\xdbE\xc7Z\x85\x90WG\x15\x12\x81Y\xbf\x90\xe73Ye\xa0\xa7\xcf\xd2\x9aC\x8b2\x1c`\xe2\x01\\\xf0w_'
        b'a\xb9A\xd4!\xc4\xaf\xf8!\r\xbd\x90h\x00\xea\xa7k\x0e\xe58\x9a\x1c\x0e\xda.\xca\xc2h\x8f\x93\xce\xdd\x97\xff\xf0Q\xf8\x8d[\x0cAL\xc2&,\xd9x\x07D\xe4\xb6\xca5\x13\x9e]\xa3\xc0\xfeLb9K\x07'
        b'\x06c\x94\xaa\xcf\xb0p\xa7\xf75\x0f\x00\xe1\x14TS#\xa4\xed4\x84\xe1\xaf\xce\xd0\x976d\xe1\xfetb!\x84\xc8\xf4_\xf2xE\x85\xfd,\xea\x0c3;;=NRs\x892C:\x030\xd6X.\xd2\xc8\xce'
        b'\x84\xc6\x08{\xd2\xc0\x05\x1cV\x97*\x8fnk\x84\xbb\xdd\xdd\x88\xeft\x8d\xd5\xd2j\xf1#-\x1ce\xe9\xc25T\xc9\xac\\<\x90_\x1f\x13A\x83vl\x82\x16\xde0\x7f\xb5\x90\x9b _\xed\xfez\x95u\xe8\xb3\xe5'
        b"(\x13\xa5\x8e\xb5\xb4\xeb\x11\xbb\xe74\x90\xffN\xab\xda\xdb\xafD\x1c\xd3\x87\x9b\xb2\xfb\xa5\x99*\xb9\x05\x16Y\xf5')\x94\xf8\xf1O\x8b>\xa2R\xeb\xe9S]\xfd\xdb\x0f\x86o3+N\x88\xb2cO\xa5\xca\xf2\xa5\xfb"
        b"\xab`u\xbd\xa0\xc8C\x9a6S\xd2\x8dI'\xb5\r\xa3.\x95\xa4\xd6}\xe9\x83\xcah\x13\x0b\xbbj\xa7\x12\xd2\x18^\xaa\xf3\x96t\x97Q\xa2\x06\xd7aL!\x14\xb6\x8d\xcb\xben\xb6\x08iG\x1eR\x94 \xf3\x9b\x9f"
        b'\xf2U\x8e7\xa8lm\x98\x8a2\x19Ia\xfd\x19W\x84\x9c"\xf0aTv\xc2,\xbb\xcd\x9b\x90\x03\xab\xc3x\x8c\x93mD\xc5x\xa6\x08}\xcb\x9f\xc1\x89\xae\xc8\xb1\x19t\xdfUp\x04\x0en\x83z91\x10t\x12'
        b'\x06\xa9KXV\xb9\xf8\xcd\xd5\x06\x1b-\x98 `\x12*\xdc\xd2\x13\x9d\x18\xfa\x0c`\x9aTi\xec\x89\xbc\xdb\xceF\x7f\x94\x06\x0f\xa3\x14\xd1\x88\x92\x7f\xbc(?:\xbd\x07\xfa\x16Lj\xf8\xbb\x91\x0bl\x02=\xd4\\-'
        b'\x8a\x86\x02fi\x13\xc8\xf9\x13\xe6\xa3\x9ex\x9bY\xbdR\x00\xaaZ9\xa5\xdf\x10t\x95\x06D4`:\x0ff`\xc2}\xe1\x1d\x9f\xfe\xe5%\xae\x00\xa4\xdc02\xbc#sU\xfd\x82\x9f\xb7]B=\xedE\xe8Y~'
        b'\xfd`\x01>\x93\x9fs\xa3\x82\xe7\x8b\x93\x95\xed\x9d7\\\x150L\x9a\xf0\xbb\xfeoa"\xbb!\xba\xee(`\xebr\x08\x0e/O)\t\x07(\x97\xf8\x03\xeb\xe8\x95\xa2\xcb\xa8Y\xd4\x19\xea\x834$\xbd\xf1\'|('
        b'\x90\xf8\xedy\xad\x82\x1d7\xfeJ\xcf*\xd9\xbc\x8aqF\xdb\xae\xda_\xb3}\xb5\x89\xbd\x1d\xcf\xe3\xb1\xdc-\x14O\x0f\x98=6\xe3\xcdpj\n\x90\xe4\xa7\x08X\x9f\x9f\xb4\xc0\x04B\xd3n\xf9|HM\xda\x98\xa4\xc6'
        b'\xc8\xade\xd9\xf7k\xc4?!B\xab\xa3+\xa7\\\x1c\x17P\xe2$l\x9c\x87\xe5:\x07\x08\x13Ol\\F7\xc5\x83\xca\xdf\xf7\x11HF!Q\xcf\xa8\x9aA\xc0u\xb6u\x0e\xad\xeal)-\xad,X\xde\x8b>Q'
        b'\x9f\xfb\xb9%\xee\xf7\x1c7&\xa1\xcb\xabGg\xf3\x95tl\xb7\x05\xc1\xdbL\xcb\xe5^\xe1\x81\x96\x12\xf7\xfe\x14\xdf\x9a\xfd\xe6Cr\x93\x82dI\x05\xf1\xb5\x15a+\xf5gG5E\xe2\xc8\xf8$\xc8!\xdf\xf99b'
        b'`\x82T\xf0\xe69\x87d\xe7\n\xee>\x9e\x8e\xec\x0f\xc0\x89\xf9c\x99*YF\x8aj\x8a\xceM\x9fVd\x0ev\xf8\x95\xd7c\xd3\xc3\xcd\xc4\xb1U>\xbb\xc8pqP5{\xf8t\xe64\xc5p\xce\x04U\x9a\x0b\\'
        b'\xfd\x8dO\xe1v\xffS\xf9a\xb1\xe8\x8f\x1b\x1a\tQR{Sp +\x83\xe7\xf7&\xd9\xc7\x92Wl\xe2\x1bm\xd6\x9f\xddq8\xee\x89\xee\xd8\x88\x0f<\xc9\x8d\x0c\x01@TR\x0b\x8b\xba\xf8\xd9\xf6cj\xb2OO'
        b"n0\xf2\x8c\xae]\xb7\x1a\x0e\xe2'\x93\x1dm\x12\x1c>#\xa7\x80=wP\xbb\x08\xe7\x96\xca(\x9b\x9fa\x9d\xde\xe2@\xa7\x8f\xd7\x97\xdb=\xd5I\x89\xd7\xe3s\xebRZ4\xc6f\x0e\xaf\xfd\xc7D\xef#\x1c\xe0\xd3"
        b'_~\xab|\x11Z\x05\x08\xf1(\x9bC-\xed\xa4\xda\xc7,e\xa9+\xd5\x03\x12N\xc5\xbbH\x8f\x07\xe2\x12t\x9b\x94\xf3\xb1\xa1\x11)\xa6I\xf5\x1aE_\x1f\xa4\xb3\xec4R\xb5\xaa`\x06S\xe34Y\x8ao3-'
        b"\xdd\xeeW\x9f.\xe7)\x08{ N\xa3\xfc\x93n\xcc\xcc\xffp\x0520=\x11z\xb9\x85\x8f\xd3\xe4\x9f\xfb\x9e\xdbF\xb3j\x8b\xee\x83l\xcc\xf2\nl\xf9\xb4W\x90\x15\xae\x7f''\xce\xc9-\xdf:\x12\xcbn\xa5\x9e"
        b'z\x93\xb7\xf8\xdf)\x80\x9dx_\x82U\x81U\xfe\x80\xf1\x11\x95(\xc6?\xb6\x97q2\x13\x04\xe7[\xa4\x8c\xaf\xae\x84Q\x94\xa3\xb8\xbc\x06\xc7(8v\xaa\x9d\xbc\xe4\x9di^.),y}4\x82nk#\xe0L'
        b'\x1fh\x95\x18)^$B.\x99L\x00\xc1\x9d\x13\xa8\x8cm\xe3\x84s\xa336\xbe\x1b\t\n\x95\x9a7P<Gi=\xc2"{2P\n(\xa6n\xc3y\x9e\x9c\x18\x14S$\xc3{\xaaX\xa3\x00\x08\x8e\x93\xb2y'
        b'\xdf\x95\xb9W\xf1\x98\x06\x17\x9e\xd4\n#\xc0\xae\xc7\xc9G\x03m@\x03v\xe7\xac\xae\xd2\x90\xd0\x08\x1f\x0bk\xc8\x83\xe05d;\xd9\x91\xcb\xef\x04\xfa\xa5g[<\x95\xe8\x9d\xf4/\xd4\xe5\xc4@\xd1\xa0\x1dng\xc9w'
        b'r\x9dpf\x9b\x00\x9b\xd4\xcd\xbb-q\xfa\xe5\xd4\x17\xe3\x02\xc0\x03\x98\x06\r\xeey5\xe1\xb6N&\x83\xcd(z\xa9\x19\xee\xcd\x11\xca3oc6/S\x9b(-\xca\x14BTh\xa6\xe1\xeee\xc5#\x9d\xdb\xf5\xe4'
        b'_\x18\x03,\x06\xc3\xdb9\x1d0p\xf5\xf8\xf5\x1f\xd0^\xfd\x87\xee"\x1d\x9cOTu\xf31\x90\'\xe7\xa5\x91\x18\x0c\x88\x05\xf9jG\x1d@&\x19\x9e@\x1a\x99\xce\x80\xe0\xd0\xadUn\x1a\xba\x06\xec\xd0\x1b\nA\xbb'
        b"\xe5R\xb3\x043\xf3]8\x86P\xa0\x1bk\xfdR\x93\xa1\xc7\xa0\x98f\xb4\x88O'\xc7C\x04\xed`-\xed\x8a\x1brD\xe0\xbcS\x17\xdb;\x9e<\xd0\x11\xd8\xb1\x839\x10\x05q2|y\xb5\xad\xe2<.\x9e_1"
        b"\xb8<\xb7P>\xf7&0\x82\xf5\xf8\xa4\xdfy\x8c\x07\xe68S.\xdb\xa3\x12\xefcxz\t.\xb2\x04\xc93!\x9b\xaa\xa6\x8c\xdf\xf5\x18`E\xee@!q\x8a\xb5\xaa\xc3\x15\x18K\xce\xdfA\xe5'o\xe7:\x9a4"
        b"\xdf\xa9\xfd.\xd0\x0fUP31w\xa1\xa3Z\xb9\x9a\x95\xadM\x89\xb4\xbfA\x02a\xdd\x93\xa0\x99\x96\xb1\t=\xdd\xd1\x9b^Z\xaa:P{\x94\x9eI(\x97X\x8b\xe4\xb7\xe3\xa8q?C'\xe7~?\x8f\xe7N["
        b'\x08\xf9\x84\xcf(7\xb5\x95\xf6\x02LlZth\x00\x18\xde5\x11\xf7b}\tv;\xda\xc1\xf8\xe0\xf7;\x0f\x9eK\x9f\xc2N\xb8\x0e\x85!\x9bh\x0c\xb0O\\x2=h\xeal\x9b\x02\xc4\xd8\xf7\xfcP\xb2\xaao'
        b'\x99i\x1d]\x15\x07\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r'
        b'\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x06\x00\x00\x00\n\x00\x0e\x01\x12\x01'
    ))
