
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']


def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    pass


class SWIFTParserError:
    """
    SWIFT parser returned an error.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s*\x00\x00\x00z\x04e\x00\x01\x00W\x00n\x07\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01e\x00e\x02e\x03d\x01d\x02'
        b'\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xd2.\x00\x00PYARMOR\x00\x00\x03\n\x00o\r\r\n\t0\xe0\x02\x00'
        b'\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x92.\x00\x00\x00\x00\x00\x00\r]\x1c\xc1\xb5\x987\r\x15\xc132\xd75\xde\x0b\x00\x00\x00\x00\x00\x00\x00\x00\x19\xfc\xe5\xc6c\x91\x87O\xef\x11\x0ck\x8c\xb7\x9e\xc5ke\x0b:\x1a'
        b'~\x00c\xf9\'\xd5\x177:\xcemA}\x10gCT\x06v/N\xb8j\x99\x1aJ^\n\xdf\x1b)\xc9\xf1\x15\x059\xb9d\xa9-\x1f]\x0e\xe5\x817\x88\x98\xf1p\x90\x04\xd2s\xea\xfe:\x8c\xca"\xfe\x8e\xcc('
        b'\xab\xa13\xa3\xe9cg\x9b\x91\xc2h\xc1\xff!\x91\xb3\xd4&B\x9b\xaf\xfc\x08\xaa\x18\xee\xbc\xebT\x9b\xce\x16\x1e\xd3{E\xf6O\xb4\xbe_"\x83\x96Kr\x9d\x1a\x15\x08B\xdek\x1a\xec\xd8\xa2\xc9\xa3\xf5\xcfqc\x9b'
        b'\x80kMT\xc5\xcaN\x0bOg<\x8a\x81N\x17\xf7%\xdb\xa9g\xcb\x84\xda,Z3\xb1\x1a&\x05W \xa0\x13n\xffpN\x92(Th\xfe\x05\x18\xc7\xde\x8c\x86\xd4\x08{\xaf\x1f\x87\x19<\xc8\xc1\xe2\x7f\x94BB'
        b'\xea\xd0\xaa\xb4\xee;3\\o\xf9\xe2\x8c\xf1\xba\x85hA>\x883+\xf0\xa87\x0e9\xd6Na\xe4\x93\x8b\xc5\xbed\x08\xb3w7;\xdc!\xfb\xadN\xff5\xd4\x08YW\xcd\\\xc9\xfb\xfdf\xc5>c\xebVFH'
        b'\xe6\\)\x872\xc2\xa2EF\x13\xde\xa7\xa5\x01\x1a(b\xbfv\xe8IN\xa32\x9b\x16M\xa8\x07\xa2\x87H\xc2\xb0e\x18\x14P\xc5\x1f\xc6!\x1a\xacj\xfa@\xc5I}H{\xa4\x8ax@\xc6\xd2\xee\x86\x83GM;'
        b"'\xa2\x16\x9e\x7f\xfb\x95{r\x0cu\xb4\x9c2\xae\xe6tJ x\x8f\xba\xfb\x85\x07\x8d\x93\x9f\x14U\x8bM\x0b\xff8uDp\xa9\xf7\x1a\xde\xc2\xcfq\xbe\xbe8\xd0s\xd9{\t\xec\x82\xbb\xad\xc6\xe7\xa1\x80o\t\xcb"
        b'\xfb\xff4\xe0jke\xc4+\xf0\x116_\xfbg\xf7C\xe7`R<!\xb9\xd8\xdc\x03~~\x94K0\x1cK\xb6\xbd\x8c\x8d\xad^\x10$\x9c\xae\xc7#\x97\x07#(`Inx\xad\xe6z\x0e\x94l\xf38\xe0\x87b'
        b'\xef\x8d\xc5\xde!\xc2\x8b\x0c\x1d\xe2a\xa6\x92\xd4\xf2\xcd\t\xa4=\xc9\xa9\x8b\x16\xb8{cO\xfe\xbc\xadR3eA\xbb?4\x94\xad\\\xea\xda\n\xdf\xec \x8a\x0e\xb7\xb44|H\x1e\x80\xf2y\xca\xed\x13B6$*'
        b"!>\x82\xdb\x9c\x1e|1R\x91\x82Op\xc57Eh\xe8\xde?\x9c!\xaa\x94\xb3\x13\xcc\xad\xb6\xfc\xbf/\x8c\x98\xdel>\xa8a4\x8c\xca\xd2\xbb4n\x90f:H'\x03\x80`\xe2\xa4\xf5q\x91\xbd+\x92\x8a\xa1"
        b"f\xd1\x9f\xa2'\r\xba\xb0\xaa\x00\xb9}\x9a\xd6\xf7\x04\xc5\x05\xb7\x0b6\xed\xbbi=c\x84:a\xd1\x9eP\x90^,\xce\xd3P<r{\xc8pR;\xe6{\xe7\xbb\x8f\xca\xc2\xd9\xb6\x80Y\x933G]\xaax\x97("
        b'2\xef\x08\xfa\xb6\x8c\xfc_\x0f\x04j\x8a\xa7\xfe\xc0gc\xd1\x17\xea\xdc\xd0\xb2\xd8|\xbe\x0e\xd8\xe0\xcb\x12sP\xf4b\xaet\xd0\xc5\xcb\xbd\xd4\xdenD\xe7\xfbn"D\x19\xdf\xc9\x99\xb2\xca\xca\x86\xa2\xd5\xf91\xbe\xd4'
        b'\xd0\xac{\xfc\xa0\xb8[\x97\xb4c\xde\x99#Q\x0c\xff\x94\x01.\x9fP\xe1\xb7]?\xa9\x13\xa8\x06\x94\x8fB\xc2w\xb2/\xec\xad\xe3\x17\xad\xae"\xeb\xd8Al\xb7\x1c\xe8\x80n\x9c\x1a\xbc\x17=\x8a\xa8\x07&\x19\x98\xd5'
        b'gv\xd0\xcfx\xa3\xbf\x89\xac\xa0\x9dF\xcc\xee0\x9d\xa7>\xfbN\xeem\xc4\xe9\xf2*XK\x05\xa0b\x16\xd4O\x8b\x8d\xe8\x95q*\xb5\xa0E8\rz\\\xfe&Nk\x98\xc67\x99\xb6\t\x99\x1a\x00\xbe@\x9d\t'
        b'\xb2\xd9A\n\nf\x10Z>\x82\xf0\xeb\x88\xf2\xc7\x8a\xc1\xd6#\xa6\xf9\xb0\\\xa4\xe2\xee\t\x88+\xea\xa8\xf3\xcb\xa2F\xb2\xcc\x17\xda\x06\xb5\xc8\xa9\x8e2\x02*\xef\x86Pw\x03\xf2$\x0e6\xf3\xd6\xaa\xaa_\xbb\x19Y'
        b'\xc3f~\x9fa\x1e+H-\\\xac\xd2E\xc5\x8eM\x18\x9cZs\x0c\xfe\xe439^\xedH\x89CY\xc5\x08\x9a\x04\xbb\xba\xa9U\x97u\xf9\xdbQ\xb3\xe3\x10\x9b\xc3]J\xec/\xc1\x1e\xba\xb9\xc22U\xaf\xcb\xa1 '
        b"\xf8\x12M\xfb\xd0K5\xfa\xd1\xcck\xa7*\x13\x05\x88\xe1\xde\xdb|o\x06-\x10\xe6^.T\x88H\xd4\xe1\x98\xfa\x1d\xe2\x11\xc3o\xbe\xf4\xa0'\xdb\x0cz\xc9\xd6\xd8|*\xb2)\x9a\xd4<\xe2y\x06\xdc\xc91\x10K"
        b'\x97\xea\xa9\x15\x9d\x81\n6\x0c\xf3\xcd\xa4\xb8\xed\xda\xb7\x08\xf0\x0b\x97\xdb\x0c*yP\x0b3+ri\xd4Z$\xc2\xb3o\xd8\xec\xec&\x1b/\xb3\xaa\x90\x15\xb3\x8e\x95dZm\xd7i\xbe\xa5\x86\xc7\xea:\x06\x10\xa1\x9a'
        b'u\xdd-\x8b\xe0\xcb\x0f\xa9\xdc7\xa9]\x98\x08\xbf\x16\xfc\xc7f`\x94S:k\x04\xc9\xef\x16\xb8i\x9dK\x95\x9er2_\xda\xa0\x9fx\xe8\x17\xd2\x12\xa6v\xe1\xaf$\x08\x17\xa8\xa0p\xaf\xab\xd8\x122[\xac^\x1c'
        b'\x96\x99\xd3\xb7ET\xbb\xc0\x83H\xb8\xc9\x87\xcf\x14\xd3\xf2h\n\xc2\xa16D\xbd\x01\xbe\xc6M\xcds~Z\x9aO\xce\xc5\xf0a\xf7\x85\xfap\xcd\x0c\x8c\xb9\xe6\xcbk+\x04n?~\xecYs\x0f\xdf~\xaa\x8b\x18\xf0'
        b'\xbdPWB?$\x8e\xe9R{YK\x8d\x1a:\xdcw9\xc7\\\xa3\x9a\ri)\x9e\xed\xd0\x07\xb1@\xb2x\xbf\x83\xc0\xff9M\xa5a:8\xfb\xfc\xd8\x9b\x02\x03[\x1e\x8a\x18o\xc4\xed\xb7\xc8\xda\xd07\xa3\xd7Q'
        b'*\xca\x0b\xbe\xa8\xdcZ\x82\x82\xc3\xd8f\xe4\x98;\xf1Tpq\xf0\x96\xe7\x0c\xc1\xc9\xa2)>\x98\x17=\xe2K\xddwu\ta\x7f\xa0h\xb0\xa0\x9a\xee\xae\xec\x0b\xc0]\x84\xf0/\xcc\xaf\xec: \xb1a\xa8L\x00m'
        b'z\x81{+nj\x9aM\xab\xfa\xe3R\xee-\xb3\x96\xc9\x844\x87\x8224\x84|\xcb>\x81: \xb5\xa2\xc4\x8e@h\xc2\xfd0\xe6\x87?v2\x87\xde\x8d\x00\x15\x03\x06\x9d\x0eO\xd8\xc1\xf2\xbd\x80\x85J1+\x9d'
        b'rZ\x04\x18\x18\xeaM<\x1bun\xcf\xb9\xa2l\xeb\xadc@x\xbf\xee\xbb\xba\xb8N\x96=Q\x06\xd4\x97\xb6A\x01\xb9X\xcc\x05\x97kyq\t5[\xa8\x8b\x8bc\xdf\\\x0e\x99\xf7`\xc3\x99\x98r6B\x04k'
        b'\xdbMQ\x06\x9d\xdc\xaflE#\x92\x9fLI\x8a\x80_\xa69\xa1\x06\x98\xa0\x80M\xac\xb1\xf1w\x9e\x15\xf9\xba\x99\xef13\xb1\xcf\x9f\x1a\xa2\x9e\xe4\xb97\x8ej\xb8mj\xa02\x99m$\xc70\x8d\xf5\xd1\xe1\xfa\xa0'
        b"\x83\xf6\xcb='}\xd4\\;\xa1\xf5\xf1\xc1\x9f\xca\x11R6\xcek\x9dT\xeb\x07\xca`>\xc0\xf5\xb4e\xab\xb7C\xf5\x92\xe3c\xc2\x99\xaf\xc0\x82\xd3L\xd0.\x10\xbeq\xe8\x15\x8c$\x87D\xc2\xa5\n\x04\x13jl\x05"
        b"\xab1\x8f\x803K>\xc7T\x8a0\xff\xda\x8cH]S\xa1\x891P3\xfda\xb4[\xdf\xe5~\xad%'5%\xa5\x0b[\xdew\xf0\xe7C\x07H\xb7\x804\xacq\x02m\xdd`\x00\x9b\xeeXi\xf5\x7f/\xe5\xa6`"
        b'\xd6\xda\xe7\xa45V\x81\x8cL\x98)\xb6\xf2\xd6\xd9\xcf\xd0\xb9\x98\x0c\x13\x0eL\xde\xdcT\n\x89x5\x91\xea<\x16L\xbd,\xa6\x0c \x82\xff\x13\x0f\x97\xe3<\xe10\xc4\xe5lm-$\x90\xef\xe9`;\xd8\xe9\xc2J'
        b"\xda\xc9q5\x8d\xddV0\x18\x7f\x1c\xc6?\xbb`\xebj\xee\xfc8\xfe\xc1\x0e|\x03\xa7\x0f*\x11\x9a\xde\\\xf1RH\xcb\x7f\xbb~\x9b\xbe\x08\xa0%\x85\x99',\xfc#\xa4\x7f\xed\x86\x07\xf9g\xe1\x1f\xadc\xceQ\xf2"
        b'`\x1f\x12W\xce\xe8\xf6<3`\xb0\x8d\xdc\n\xf8\xd2\x1b\x11A\xa63Un\x8c\x18\x15\xf3\xbc\x02\x15\xaeQh\xc7}\xdc\xc2d\xabr\xa0\x9bO\x0c\xe4\xa3\x12+\xed[\xc2\xfd\t\xa1\x0e\x829\xcdAiI\x0e\xfe~'
        b'\xd4\x11\x12\xf1\xa2\xa4\xcd\x81\xfc\xbfC\xa4kO\xeboci\xb8\xca\x93\xa6\xc9>\xd6Z+2i314\xf7\x96\xa6\xf7\x8d\x0e8G\xe2\xc3O\xd1b\x9a0\x9e\xa9V\x8a\x1b\xb5Kv|\x82\x03\xc8\x16X\x08l,'
        b'\xef\x19\xdc6\xc5\r=o\x03\xcf\x80\\?g\x9e\x1bl\xde\x98\xf0&\xb9\x7f#\x9b\xef\xa8\x05H\x15h{\x15\x08\x8eu\x968\xeb\xdd \xd05\x11\xc1\x11Wo.I\x9c%;c\x99^Nf\x8a\x0e\xd1\xd4\xd7v'
        b'\x03\xd7\x10\xa1n\x80\x86B\x8c\xc9Pw\xdc\xa9\x90\x93\x1d\xb6\xee\xb3\x05\xeed[j>_:\xd7l\xfa"\xb8\x96\x9c\xe4\xac\x96F\x8aH\'\x94VI\x1b\xb9\x1f\xe3\x9d\xe8w\x1cJ\x92U_\xb7x\xb6-\xe9v\x0b'
        b'\xc7MX\x07A\xad\xf4\x12t\xa341\x0c\xf4\x9du\x1c\xa7\x81\xf3\xd7\xc2%\x08\x11\xea\xa9R\xc4\xc03E\x0c\x15u\xd8,\x93)3\xbeZa=\xfe\xbe\x8aQ\x9f\xd0%v\x9b\xcb^\xdf\x81\x0ex\xe0NQM]'
        b'B\x1a\x00z\xc1\xbaP6 \xa9\xd7\xbeDM\xc0+\xa6\xbf\x9e\xe3A\xaaOoO\xd0\r=\x93\xcd\xc1i\t\x18\xc9s\xe8\x1f\x1bZU\x8a\x1dB\xc3\x12\x12\xb1.T\xec\x1e\xf9\xb0\xf2\xb4\x06\xf4\x98XQ\xc0\x92\x12'
        b'7p\x14\x92\x8b+\xb8\x98+\x90K\xa5m\xb6\xc6\xfde\x1f\r>\x87\x98\x93n\xa5\xd7xetz\xc9\x99468+$]\xadq\x81%\xde\xe0\xe0\x02\x11\x18Dq\xd0\\\x17\xdcC\n\x119Z\x85\xbd\xaa\x1c\x15'
        b'\x95\x0e\x934\xe2G\xc9Z\xefZ\x94o\x92\x89\x006h\x0cC\x9e\xb9z\xe4@\r\xc6p"\xa9\xd0oII\xae\n\x87\xdfO\xe2\t.o\xea\x0e\xc1\x8a\xa0\xedp;\xa5\xd4\x9f\xaa\xad\xfa)N%1z\x8f\xb3\x1b'
        b'\xcf\x8d#x\xe2\xd6\xe2,y\xaf\x94r\xda\xa8\xe6w\xe4}8\x89\xfd\xd4\xcd\xdc\xc1\xcfV\x88\x93\x83\xd08\xc9\xf7i\xf6\x9d\xc0\x0eA\x05\xe6dW\xae\x05-\xea"\x8d\xfa$\xd7I\x97\x8e5_\x92\xc5\xfb\x1e\xd5\xb5'
        b'\\\x8af\xd4\xd8\x9a\xb0\xddh\x7f\xfd\x85\x08U\x1b\xf0\x82\xa2\xa2\x91\xbd\xe1\x96j\xb3\x8c\xaf<\xe1\x1b\xc2\xd0\x82\xfd\xdeB\x82g@\x85\xf9;U\xbb[\x85J_\x93\xba\x1e\xb9\x85\xef!:\x9c\xa1\x98\xb4\xe2\xe4\x17\xc5'
        b"\xc1\xc5#va'\xd8\x0e\x9c\xa7\xe8\xe5\xc6U\x85\xc2\x10\xa43\x8cq\x83\xf8x\xcem\xb3\x0c\xef\xcf\xcd\x93!(X\x12\xcax2oB\x1aS\xed\xfddx\xb8\xc6\xd3\xb0[)OLw\x12N0\xc1(\xf0\xd76"
        b'\x81j2n\xa4\xa3-gE:\xe2\x8dsV\xe7\xd2y\r-\xddI4;d\x97@J\x91\xd0?\x02d\xc9\xa2\xed\xcf\x1f0\xe2\xa5/jT\x94\xe52\xb8\x80\xc0c\xff\x1e\xc0\x99&Sx\x91\xad^Y\xba\xc7\xe6'
        b'yt\xc6\xc1\xe9\xceg\xd0\xd4/\x1e\xba\xc8\x06\x1f\x83\xfd\x86\xa8l\x12]\xd4\xca\x89-\xe6\xfe`\xc2b\x15\xe8\r\xc7r\xeer\tqB\x1c\x06\x1e\xe0\xdf\xa1L\x95\xea\x02\xef \x89\xbf>\xc6\xad\xc2ba\x8a\x17\xb1'
        b'G"\xbcO\xfe\xf6~\x12\xeb\xac\xe0W\x13(\x17\xd2\x95(\x8c\xcb\xe1G\x98\x19\xd1C\'\x1ai\x13\x8e{\xb0\xbd\n\xeb\x9f\xedq\xa3hu\x86+\x95\xcd$\xa0\x1c\x0f\xe0\x1c\xec\xf8\xb5\xa2\xda\xd0=\xaag;\xa1|'
        b'i\xea\xf9\xcdv\x96=\x88\x94\xe4n\x04rH\x08\xa8\xbe\x97\xf3\xe0\xd0\xea\x14\xf1}l-\xcd\x1f\x17\xbfx\x88or\x03\x0b\xfb\xee@\xde\x87\xd1f\xa0\r\x93&\xfc\xdf\x97\xebA\xa3\x85\xa5\xac\xaflE\x9f{{\xbf'
        b'\x90\x03z\xb9\x0f\xe1\x86\x03\xf9\xaf\xe2\xf2\xeb\xb4\x12\xe4nW\xc6\x98\xdd\xaeC\xd9\xc0 \xba\xd9\xf7_\x15\x15\x8b\xa0\x07\x00\x80\xc0E\x0e\r\xe0\r\xef*\xcb\xa4~G>\x00Z-E\xf2?\xbcl\xe1vf\xa9\xae\xb3'
        b'u4\x87\xb3\xda\x1c\x8a|>3W\x07\xab\x16\xc5\xcbi\xb9\xf4Y\x13\x92B\xce\xa4\xf5>\xef\xdcQ\xfcl\x8b\xf8\xe5\xcc\x8d\\\xa5\x19\x0c\xc5\xf84:L>x\xcca\xdf\xae\xbd\xf8\xe5\xcc\xa0|\xad$1\xda\xd1a'
        b'0\xd4\x07\xd4\xec\xaf\xaa7\x0e\xb4\x92\xcf\xf0\xe2g\x04\x84\xc7\xc3\x88\x1b<\xc5\xab\xcb\xed \x077f`\\\xf9P\xf9\xc6\xb6\xaf!\x0f}tQ\x89eBJ\xefG\x93^n2\xcd\x17\x11\xba\xa3L\x1a\xeb\x81\x99\xa7'
        b"G'\xd8\x8d\xd7\xca\x07\xf2M\x8e\x1d\xcef\xa0\x8c\xa6\x1d<\x82V5%\t\xde\xa8\x97\xe0\xa7\x1bp[ 8f\xc1\xb7\xa4\xeab\xa0\xb0\xac\xd5\xf8\x03V\xba\xe9$\x98b\xcf\x98\x89\x1e\xa41j\xa6\x96\x03KS\x03"
        b'$\xc8\x94\x8ef\x9f\x00E\xcd\x9d\x9dF\xc5,\x86{\x9c\xe9\xf5\x7fT^\x8eI\xb0Zu\xd4\xa4\x98a3\xb3@\x98\x9e(\xff\xd7=B\xf5\xf3\xdc\xa1Giy\xe07\xf7\xacN`-\xd36S\x8ec,\xf16B'
        b'&k\x13\x08\x8a\x85\xe5\x9fw\xbb+\x94TB\xc0\x13KWO%\xdb\xd0\xd7\x19\xcd \xd3ah\x1b\xdc\x0f\x9bfY\x0e\xb5\xb2K\xcaK#P\xf2u\x0f\xf8\xd2\x11s\x95Y\x91\xd9\xee\xcc\x8cdk\xaf\xd9\xdd\xabT'
        b'Q\x8b\xae\x9a\x05\x01\xfb\x8ch\x9d\\\xa6@R:\xb5\xe3\xcak\x1b\xb6\xf8m\x8a\xf9\xc4i\xd0\x1b\xf2\xcb\x13q\x97\x1e\x18\xcf\xf5M\xe2\xc5\x84\x9d\\\x82\x88/\x12\x93\xe5\x11\x83\xa4\x05\xc1\xa3m\x91b\x9aw\xa0K\xe1'
        b'\x9b3\xe3\x00\xf9?r\x86Qt\\\x06\xcaC\xe8(y\xd0\xabrS\x93D\xa6k\xb1\x07\xddC\xde\x04!\xda\xc7\xe4%\x07\xd6d\xef1\xc2\xd5k\xa6\x02\xd2a\xbc\xa2i\x87~\xb8\xdd\x1d\x05x\x80\xd1+\xdd\xf9\xcd'
        b'\xc8z\xcd\xe7mPO\xb2\xf7?a\x12w@\x90\xc3\xc4\\!\xc7!\xbc\xbc\x80OJ\xd2\xe9}\x8d\xe5h\xa4\xb0\nrT\x9b\xccN\x0e(t\x80\xccYh\x13\x8aJ2\xc2\xdc,B\xc3\xa2\x9e7b\x8c\xe0\r\xdf'
        b'\xfa&\xd6\xc0\xce\x16\x8c\x95\xa0\xe3\xae\xdc\xc0L\xf8G\xab+\x8f\x17FZ\xa0+Z\xdf\x86\x06\xe0\x06y\xbcOp\x0few\xd7\xc3\xea\xbe\xab*)\x81\xe4\x86\x99)+\x80\x9d\xa2a~\xfe\xfa\xe5\x81gOJ\xfd\xbc'
        b'\xe0\x88\xecO\xc8\x81\xcb\xfd\xe8ZuQl\x13+o.]`\x93\xd2B\x01\xb492E]\x0e>/<1\x9eJo\xbfQO\xf8o\xe10\xeae\nu\x06v7%\x90\xf2\xb9k\xa7P\x85\xf2A\x80\xc9\xfab'
        b'\xee\xa5?\xdd\xe5\x0f\x1e\xec\xa0\xf9Z\x91M\xbc\xa5=\xc3\xc0"\x80\t\xc8e\xe2S\x1c\x136~\t\xce\xab\xc7\x88\x04\xdd#x\xb7Y\xb4uRF\x97$\xdc\xea%\x87Z\xa1\xacz\xa4G\x88\x0c\xe5<0\xd1\xcb\x08'
        b'_\xc8\xae,\x99\x10d`\xd2\xbd2\x1doG\x12\x1f\xd4\xd6\x806t!\\M\xc4\xf4,f\xf7\x84\x97`K\xca\x97\xe7\x1aR\xd4\xeaZ@#@\xa4@\xd0\x10\xd5?\x01<Z\xbfW1\xf7 ^lh+\xd9\xb9'
        b'\n=\xfc(\x14wK!\xc5\xe1\x08\x14^\x98\xd8\xdf\xec\xeb)\xa0m\xb4\xd5z\xe0\x94\xc5\xbf\xa1\xea\x8b\x94\x98\xc0\xb8\xd4\xa7\x9f\xb29\x9f(\xd7\r\xec\xf27\xd7\xfff-\x1d4\xfbQs\x9a7\x9a\xbff;0b'
        b'\xb8Rm\xe9\xd2\xd0\xe5\xb56\xdb\x07o\x1c\xa7\x8f+\x99\x85\xde\xb8\xb1L8g\xf5MD\xd3\x17\t\x97q[\x8a\x19\x91\x0b\x0c\xbaa\x958\x9d<\x17A/\xb2\x9a.\x91T\xeb\x7f\xdc\xd1\xc7\x04\x92\xebu\x11\x84#'
        b'X\xd9h\x97w\x11J\xabC\x9bX\x82\x9b\xc6\xddi\xe4_\x08 W,Cz3\xbd(y\xa7\xca\xb4\x08n\xd4\x11g~\xad\xcdnO\xd0\xc9H\xc9C\x1dw\x1a`\x05\\!\xdb.\x1aGuzIl;\xce\x98'
        b"\x9f\xdf\xa4\xfb~`\x04)\x9f\xfc\x9b&\xb1\x94\xbdu<\x03\xdco\x17\xd9E\xdd\x8b\x9e\x12\x95\x96\x87\x80\xa5\xca\x85\xc5Dq\xe4\x14\xda\xb9@b.\x08\xfaY\xca'\xee[\xb1\xdf\x97\x17\\\x86p\xc0\xd0\xa4\xed4\xba"
        b'\xcb\xbe{\x03\xeb}\t\xf0\x02>\xb5ip\xac&W\xb0\x1c\x82\x0e\x16\xf7\xfceXv\xc1\x02>\xf3$=\x93ICb\x14\xc3\xf6\x9b\xcdd&\xa6\xe7\xdc\x92\x1a)qc\xfc\xf0\x83\xed1)\x83\xe1x\xe4\x9e:z'
        b"\x16\xf2\xe4\xf80\x08\x8e\x0b\x12\x17\x9eh\x0b5\xc5 \xd2\x88!\x85s\x06c\xe2\xda\xab\x11\xe3\x13\xbcM\xa8R\t\xd1\xb5\xc4\x9b\x15]\xa4\xde\xa0\xafo\x0e\xaai\xdb\x12\xf1t\xb9|\xa6wS6\x10X'7\xe0N"
        b"\x88E\xc3\xf8\xb3\xbd\xc5c8]\xa6MG\xc4\x93^\xcc\xb2;\xe3`\xff\xd6\xd9M\x8d\xb3\xa6\xce\xb5\x0b\x8bk\x039\xf7\x9e\x1d[\x83NLC\xd99\x13\x0b\xe98>\xf1'\xa2\xca\xf72U'\xe8K\xdc\x0b\xdfd"
        b'X\xcc\xd9%\xc8E*\xbb\xd0\xab\x95+\xa0.\x8f0\x0e=\xf1\xab\x05\x9b\x00\x0eH\xed"\xfcDkyZ\x0c0\x80&=\xe6s<\xbd\x19\xac\x1e\x0fno\x8e\x9e)\xa4L^\x03\xbf\xb8\x95q5s\x82\x87\x18\x07'
        b'F\xf4\x9b\xbe\xfb\x84\xd6\xe7\x0f\x93{\x86\xc0lK$G\x92\x02J\xad\x03\x84\xb6\xc8\xf9\xe9gK\xcc\xfb\xee\x1d\x99g\xd0\x9f\x90y\xae3\x00\x1f\x80\xf4\xb1\x9ec\xae\xf9\xb0/\xc5\xbap\xf7=\xfd\xd4\x16\xef\xf8\xe7\xc2'
        b"\xf1\xdc\x94\xf5$\xcd\xc1y\x08\x8a\x9e\xbf\xad\\'\xb3\xee\xe8\xb4\xa0M\x1f/)0i\x1cj\x05\x93\xf8>\x1f\x9c_}\xfc\xa0\x1a\xa3\x0e\x0b+\xfa\xc7\x96z\x9a\x8c\xe4\x1d\x0bo\xc9Q\x08:5\x17b\xb1*\xc0\x1b"
        b'\xb4\x0ceM\xa2L\n\xb1\xc7} ux\x17L\x7fR\x01\xe1I"GW\xad\xe0"\xeaD\xe8\r\x19dd\xae\xa9(\x90}\xfesN\xa9n\x9d\xe5@f\xf3\x93*\x0e\xbe\x94\xe7`\x87\x0c\xe2\xddH\x8c~v;'
        b'\x1cm\xd7\xef<\xeaK\x8cR\x0c\x92(\xfe\x93\xe6c\xfb\xcb \xaa[1\xf2VN\x1f\xcd\\\xd1\x93G<0\xa6\xae\xf5\t\x04;H\xdf\x18\xf8\xc1\xf0GI\x7fw\x88\xc6\x8ev\xec\xe1U\x8e\xf0\xddUq3\xd0y'
        b'\x8b\x9a\xbf\x1f\x05\x91I\xeb\x01Z\xa1\xae\x0b\x82\n{\xe5@\x08\xde\xf8\x14\xc9\x99\n;\xef\x99\x1e+\xd2\x95F!\xbaC\xf5Z\x85\xcd 6u\x18\xa4O`T\x8d\x0e\tI\xb1\xccB\xc4\x0e\xc7\xfb\xdd\x0f\x16;\xa5'
        b'\x11r\xe4{Q\x94Bs\x8a\xf2K\x8bU\x11\xe5\xcf\x13\xba\x7f\xb7\xa8\x9f-n\x85H\x1d\xca\x94EO\x01\xf5\xd3a\xc5\x9f\xc1\x88\x15.\xb9\nFn\xbd9\xb5I\xf2\xe8\x95\xed]\xf1\xf1\xe7\x80j\x94,n\xa4\x9a'
        b'\xd8y \xdb{r\x97\x88\x95\xb1g\x8bM\xfb<\x19\x9e4\x92\xa2\xcf\x0fQ.\xeb\xd9\xa7\xf6\xb1Y\xb9%\x06\x03\xd4/\xecU\x90I\xb4\xdc\xdeC\x94\x19\xaf1\xa4\xdd\xfa\xb7\x94Zax\x84\xe0\xb9MF\x93\x9e\xef'
        b'\x1d\x87]g\x84\x96#f\x97\xfa\xe7\xe2{\x8e,\xc9`k\xe7\x89\xe9y\xefiIT\xf7k\xe0a \x04V4\x91\x9b\xc3\xd8\xed\t\x8b\x9e\x08\xf6 \xd19\xf2\xb0\xd9\xaa\xae\xd63\xed\xd0\xc2\xec\x0e\xae\x00qt\x9e'
        b'`r\xab\xf8\x85\xd4\x89,}\x95\xd7\xfa\xcf\x16\x93\xaez\xfe\xdf\x96\x10\xe6\xd4)\xaf\x1d\x13\xe2\x80\xb6\xc1\x1f\x93>\xfd6\xa5\xb4\xb2d\x19an\x86\r:\xa0\xe0\xd9hh\xdb_PQ+\x04`\xd7i:D\xefS'
        b'\x902&\x03c\x12\xaa\x15\xdeA\xf5\xd8\t\xfc\x06\xc1\xd6m\x9ee\xad7M} \x85m)\xc4]\xfc\x04t\x86\x87\x92\x11\xa4E\xc5\xf5\xf2\xdcy\xa3\xa5\x91H\xd7\x83\x03@\xc2\x1e%\x8e\xd2\xa0\xa3.\xdd\xa7\xf7e'
        b'g\xd2\x84e=\t0ap\xec\xaa\xf7o\xab\x1b\x8a7\xaasW_\xb6\xb0\xb9\xc6\xe7>\x17\xacx\xb2.\xf6\x0c%\x85\r\xc9\xd2\xf5\x8e%\xd9\x12\x1c\xc1\xe3\xe9f\x9bQ\xca\xfa\x93B\xc8/\xacIc\x9bRK\x16'
        b'?\x96\xc4E\xc7\x8e`1\x01o9\xa4\xbb\xb4\xc5e\x9f\xdf\xc9\x84\xd7\xe2\x94}Z\x19oe{\xe7\x9f"\x17^\x9c\xe15\xc5+\x92\xc0(\xc6\xbf\xa0\xc7\x17\xef/.]\x8e\x8d\xff\x9a+T\x1c\n\xc0\xfe9\xb8\x9a'
        b'/\x8f\\\xea&\x89`H\x8a\x11\xdc\x117?\x9e\xcf\xba\xbd|y<)\xc4\xf7,\x156A41\xff\x1b\x9c\x928\xee?%\xb8\\J\x0f\x8b\x8d)\xa3\xa3\xcb\xa9l\xfa\x8e`\\\x7fK\xbe\xe0\x1e\xa7\x94W\xd1\x88'
        b'j|\'eN\xda\x93\x0bgyi\xe7\x9af\xf8g}\xc9\xce\xd7k\x82\x14\x9d\xe0^\xb3\xb5:\xd3F\xa51\xa1\x8ak\xaez\xe9To\x99\x9cC%\xd3\x82,K\x98b\xa0\x07C?\x1bn"\x8d\xa75F\x02]'
        b'\xfe\xd2\x8bj}D0r\xca\xe2\xf6\x9ane\xd9\xb4v\xffP\xa4\xd3\x90\x83\x8e\xcfj\nmP\xa8\x0e\xe3:\xe0+gR\xaf\x8a\x81z\xd1\xfc\xa1\x07\x1dSz\x04#~\xb8\xd6\xa0c\x0f\x89\x7f\x9bnV\x97\x9e0'
        b'\x08@~a\xc4\xef2\xba1\x00\xb3+\xa3\x97\xac\xc1\xfaG7\xa3\xb9SHbX\xf1\xa7\xaf\x84]\xb7h\xaaV\xf6%=\xae\x1e=X\x05\xd0\xec\t\xf4\x8d\xd7\x90P\x14\xba\xfc\xd21_\xe4\xcaH\x0eP`9\xa0'
        b"\xe9OWc\xca\xb1;\x19\xe2/\x7fOy\xd7\xed|\xc4\xb8\x9e\xaa\x81\xf4\x9f\x8a2\x9a\xff\x00\xdbM\xef\xec\x8bH\xe4\xc6L\xc6xl'\x06\xb5\xf6\xc2\xc9\x8d\xdaO3]\xfe7\x8f<\xb3\x0c\x12\xf8\xdcM\x17\xa3\xa6"
        b'\x81\xe6\xd0\r|\xbd@\x8dj?D\xcfk\x8b E\x8b\x0b\xfe)\x0c\xe7\t#\x88\xfe\xc7D\x812f\x922\xc2)\x1d.\xe9\xc5\x88\xbd\xbe\x83\x1aO\xb6q\xf6\xe2Xu\xbb\xa9S\x0b\xea\x03D\x83\x94p\xa2\x1e\xba'
        b'\xcf\xafW\xce\x9a}\x8f\xaen13\x85\xa6\xbe\xee\xbc\x1a>\xae\n(\x18\x01\xb9#\x90\x0e\xe4#\xf6\xe6tw\x0fW\x87\xa9\xe2\xd6\xfc\xd2\x0bu2l.\xdd&^ke\xa1\xa0v\xe3\xd9\x0bw_6&\xbf\xaa.'
        b'\xac9\xae]\xca\x9eBf\x94\xb7\xf4\x08\xc9\xc6\xa0\xb0\xf7.\xd4\xa5\x11\x12 `\xab\x84\xb8s\xc75\xd4\xf9t\x00\x17<\xa05B\xfa\xa3\x03$\x84\xf89\xad\xf2\x1b\xa3}\x86\x88\xad#\xdd\x95\x900V\xbc\xce\xfb\xe2'
        b'?R\x86x\x166\xdaX\xcej\xc9\x83r\xfb!<\xe7\xc0\x8a\xab\x8f/4T\x1a5n\xd10\x8d\x9e\xa8`\xb0\xa3F\x0eG\xb6J\xa2\x85\xeaug\x1c\xd8\xe01D\x0fe!\xd7\xbfYF\x132\x8a.K=\xda'
        b'4k&.\xfax_7\xfew\xcd\x95-:\xd1\xaa\xa6\xce.\xb9\x88!\xcc\xf3\xf8}\x96h\x9d\xf5\xbf\xfd\xc0\x07@X\xea\xb8:\x1e+\xa0$\xbd\xbf9\xf8\xb0l\xac\xe9P &:v\xc5\x08$D\x9eP\xb2\xd7'
        b'\x04\xbfox0L\x95\x1aS\xeb\xba\xcaa\x8a\x08\x0e\xe5E]\xff3\xd6\xaa0\xdb\xf0 \xb7\xa1K\x0b \x98\x82\xb5J\xac\xb5\x11\xc4\xe8\xf6\x0b\xa2?\xb7_\x14m\xe7BH5\xcb\x1al7i\x95\x16">\x14-'
        b'\xc4{\xed\xe3\xeb\x1cP\xcdd/,\xf5\xf0\x9a\xb8(\x84\xe9\xdbV\x1e\x13\x85[\x08|\x107\xd5]\xcf\xbf\x99Zw\xa1w\xeb\xa0y-\xff\'\x8d\x9a\xc2"\xc4v\xc1%\x9d\x87\x00\x9c\xa6\xec\x8f\xaf\xb0\x7f\x99\xff\xc8'
        b"t\xfdq\xd6^\xe1\xbdW\xda\xb8Z^\xf5\xad\x04#d\xe1\r7\xa9\xfe\xd9\xef'\x9a\xc1i\xf4\xae\xceEOoS\xa0\xb4g\x82X7pE\xd7\x99\xd3\xd8\xe6\xe9\xc8\x16\xff\x13\xef\xd3\xda\x17c\x98\xa6uS\xcf!"
        b'\x82\xca\x16Lu$N\xdc\x9b\x81\xd7\xe0E\x8f\xc7(\x86\x91\xa1\xbeg\x0cM\xea\x1c\xd5\xed\x82\xef"\rj\x0e0\x81L\x94\xea\xba\xa5\x15B*/\x93\xd7v5o\x1a\x06\xbb\xfaI\x1c\x7f@\xeb0p]\x8e\xd35'
        b'\x824\xf9\xd3\x85\xb10\xa3\xe4HpY\xd8\x9e=i\x93\x87\xaf\xb1\xa5y\xba\xc2\xe07\xd7\xde[t\x1ci\x7f\x9f\x9e\x14\xe5\xdf]\xf8\x8c@\x98\x90g\x12\xf4>\x034\x8f1\xb9\x9d\xab\xf8\xd1\x1f\xff\x94\xbe.c\xd1'
        b'\xc1\x05\x88O\xc7\xdc_\xad\xb5\xeb-k}\xf7Fv_2]\x9bl\x95=\x9c\x80\xb2;:\xee\xfe\xae`\xf0N\x8b6.\xb1Ps\x19x\xec\xe0\x84\xe0\xb7\xdb\x8bwr\xf9\xf4\xc1T\xff%\xda\xe8\xd8\x87$\x89\xc1'
        b'\x9c\xe9\tz\xa82D\x9dSI1\x02\xfe\xb55\xbb\x17\x92zD-\xbdh\xf4\xa1w\xdf\xf3M\x83b\xdf\xfd\xaex\xaci\xd2\xd1\xa5\x0b\xdd\xf9\xe5!mu\x15\xbc\xbb\x19\xb3\x9a6F4\xc7\xd7v\x10dZ\x11\xf0'
        b'\x94I\xe8\xfbN\r\x82\xae\xd4\xfc\x8fA\x00o\xc4\xe8Dr\xa9\x97\x1f\xe8\xe0\x9c\xef\xde\x1d\xe6\xb5$\xb8V\xc9\x8b\x10\xf4\xb6A\x84\xb7\xabS\xa5e\xafP]\x15NW\xbe\x8b\xcf\xeeN\xb7\x8cZ\x8d\x82\xbb\xa1p6'
        b"\nZu\xd5#\xe8\xba\r\xdb\xc9\xf7\x81\x96-\x9c'\x8f\xa2w\xe3\xa6\x99\x88\xa8`mb\x7fx\x18\xd6\x8b\xae;\x88\\\x05CS\xa8F~:\x19\x80\xb0\x1c+3G\x85Nf\x92\xb3\xa4\xbd\x02C\x90\xbd_\xc3\x0b"
        b"\xdd/\xa07\xa1\xa9\xa4\xdbz\xb9T\xb6\x9f\x88\xc1\x1e\xc2\x91\x96\xe4\xa2pL\xa63wLl\x07\x9a.\x02\xceP\x95\to\x9d\xec\xee\xfa\xd6\xdd\x98\xbd\xa5\xae'\xd5\xa8\xc0)n\xc9\xb8aO\x076\x90\xef\xbd\x86\xf2"
        b'\x0c\x18=-\x1e\xdaUB\xd6\xeeZY\t\xe3\x1dq\xcb\xb5\x9a\x8c\x96@\xc6\xc5\xd4H\x1es\x99\x85{\xad\xe0\x84\x89n\xc9\xc4\x81\xcd\x0b\x90\\\xc6\xef\x05\xc4^\x15\x88\x98\xc4T%v\xa0\xef\xc4\x1dr!\xd1\x16\x18'
        b"\x01+\xfb\x9c\xab\xfd\x86\xaaupZ\xe8Zh\x8bOX2\xc7D\xfb\x98\x91(!eB\xf2\xfc\xe5\xae}\xc9\xf2\xe2\xd2r#\x1a'\xa3q\xd6;\xb6z\xed\xfeI$\xcc\x1a+\x1d\\b\xed2j\xf5Z\xf7 \xc7"
        b'\xa8\x16R*\x9eX\xbc\xc0\\\x08\x9c]?\xdb\x91\xbbd?\xe4n\x9c\xb5\xc3\x96\xe7F\x8a|\xfaa\x80-\x7f\xf9\x86\xa5\xf9\xe1\x0c\xa2sE\xb6\x0f9\xec\xb9\xd6\x01\x87\x84n\xf9\xc9x\xb6\xc1\x1d\xb6\x9b\xde\xe9\xefL'
        b'#\xec4\xc6\xca\x85B\x10\x84\x9b\x8eN\x1b\x11 \xb16\x1a\xb8R\x85@\xec\x96\x04j\xc7\xe7\x95\xae4\\\xbd\x00\xdbJ0\xcf\xa7\xbb\x81\x99Y-\xdf\xb1r"\xdb\xd8%;\xc5I\xf9kZ\x03q\x96\x85\xffv\x1d'
        b'A\x17\xfe\xae\x176J\x02\x8cN\xd1\xb1\x08\xbe\xec\xbeT\x0c\x02\xc9\xb1\xa1\xc4_\xb2*\xd9\xda\xc6\x8e.\x02y\xc3k\x94\x80K\xa4\x19s\xa8\x04Se\xf1k\xd2R\xec\xf5\x9dzS|\x04\xaf\x80~\xbf\xb9\xae\xcbM'
        b"p\x90*\xbb{\xda\x03B\x00/\xabo\xe5r\x902\xfaaF\x8cI\x98y\xce[4\xb9F\xdb{\x1a\x13\x8b\x16\x13\xae\xd3MB\x04\xd3'M\xa6y\xd4\xcc\x91\t\x87^7\xc8\x8f\x8e-^\x15/i\x01m>D"
        b'3^\xe2$\xe0\x88\xe4\xdf,b\xb3\xeb>\xea\xbe+/\x02\x9e}\xfb_\x7f\xcd\xe75a\xbaj^_\xfcv\xe3\xfeiX4\x1f\xfd\xb0T\x16\xb2\xf3\xfb\xcb\x1e\xf4E\x94\xcas\t\xe0\xd3\xc2A\xee\x84\x80V\xf4\x1a'
        b'H\x87-\x103n\x92.\x00I\x03\\\x14dy\xdd\xb0\x9c\x9a_\x96\xeb \xe6\x06\xaa\x0bN\x97\xf5\xee\x0f\xc0\x07!\x14\x94\xcb\x07\xdaI\xa4\x95\xfe\x85\x88d\xd3\xc4[l\xbaK\x15:\x9b\x05\x1a&[\x8f\x10F\xa8'
        b'\xa4m*K\xe1\xafv)c|\x0e\xfa\x9f\xd6\x1c\x83I~9\x1c\xf95\x0c\xe9\xf8\x7f\xc5\x19]\xd7F\x95d\x7f\xdf4\xbdpf\x14J\xfb\xa8|\x0cj\x89_\xc1T\xb1\x9fEz\xec\x04\x10\xccR5\x82\x94\xb10'
        b'\x1e\x1e\x8aq\x0b\x9c\x98R\xcd\xe5J\xfck\x97\x9fs\xf2\xcb\xb0@\x92\xfd(Z\xe1a\xc3\xf6<\xef\x07}F\xaf\xe1\xd7\xb9\xe6(\xda\xed\x98\xdf\xf1\xae\xfbm\xa3W\x82*a?B\xac\xac\xc9Z\xdc\xd5q\x04b\xa9'
        b'\x0f}\t\x03\xfb\x11\xb2.\xa9\xc2\xc2\xe1\xea\xb8t\xfdb\x15\xd9c\xcb\xba[q4z\xea!-\']Suu:\xb4\xbe"\x97p\xb4\xa4\xad\xd8\xe6\xd7\xe9W!\xf8\x97/\x88\xc5\x1a\xe5\x05\xcd\xe8\rL\xfd|!'
        b'\xe8O\x9c\xa1\x17&\x83\xe7\xedh\x88\xfb,\xbdC\x02t\xe3&\xac\\k\xd0\x1a\xf5\x184\xb7\xffF\x05\x10gq/\xd4L\x8a\x81\x7f\xaeuR\xb3>\xa0(\x9aH\xe4M\x8e;r\x84`\xfb\x8d\xd1\x93\xbbm\x9c\xb0'
        b'\xa6Z\xc4\xc7\xc8\x9c;\xc5^\xba\xb9U#\xa7\xc4\xde\xa6\xab%\xecDr\xd2\xab\x89\x8a\xc3\x82vs\x90\xcdg\xf4\xc7%\x817\x03"\xc3M\x10*#](\xa6<\x12cy\x85F\xb4\x12\xd0W\xb9\x97\x88\xe0zF'
        b"\xe4=\xc8q!z;\x1c\xa7N[1\xdb\xe3a\x0fDv\xc39\xa0\xfe\xc0':\xffX\xe3\xf3d\x9bl\xe0\xab\xe3g\xc0\x1f\xa5\x85<\xab\xf1\xc0\xbf\x863G-j\xbc\x00\xf8_Zz\x1a\xd6\xfc\xcce\xf2@\xd4"
        b'\xd1\xd7\xfe\xe3+\x8as5u\xdc\x85\xc5\x7f\x81\xfc\x0c\xcaO\x13?\xe3\xf1\x04\x12\x93P\x89\x01\x1c\xa9\xcf\x90n\xb3\x90\xe8\xf0\x04\xa9\xc3h\xf8G{K\x85\x8fP+6\x08\x17q\t\xd8\x08\x08n\xcc\x84e\xde\x0e\x88'
        b'\xb0=\xa9[2\xc1\xa0\xfa^\xcd\xb4\x1c\x1e\xb6\xf5L`\x94M\x0c\x1c\x15\x95\xa5\xe6\x0c \x86\xca:Z\x926u\xf5\xaa\xd1\x00\xf2\xd6\x18\xed\xd9\x1a8g\x95\xbf\x16\x93\x9c\xb0w\xbd}U8\xb1y?t^\xa0\xae'
        b'3\x99\xb9j\x87\x005b\x82\xaaZ\xb6\xd8+\xa5\xc2\x18\xca\xf4\xe6\xdf\x7f\xd0\x9f\xc0\xb4;\x10\xb0\x18Z\xfc\xca\xe4\xae2\xa0\x9c\xe4\xa7\xaa\x90X<4\xfe\xe2@u\x07\xd9(\xf0\xb7\x19r\x0b:Y\x11\xeb\xa5\xba\xc5'
        b'\xd5\x1bBi\xbb\x1a\xd7\xe1f\x87]"\x84\x85\xe49{hie\xaeJjMvT\x8f\xef>b\xb7z\xf6\xe7\xd6\xcf\xf3+\xe7>^\xc4\xb61~\x1d\x18u\xe8\xfb\r\x8c\xe6N\x12\xafjA\xac-\r\xf8\xd6\xed'
        b'\xfd\xaf\x96\xed\x1f\xd3\x01F\xe2\xc6V\xfcG\xd6s\x01\xe3\xa3\x07\xd4\xd3\x03\x01\xc3\x04\x123\x13\xb4~\x82u\x9f\x0f\xb8QY71\x8e\xde6e\xe5\xce\xafX"\xe8\xa5\xb6E\x1f\x9f:\xe7\x18m\xe9Bd\xe1\n\xbb'
        b'\x8cky@iw\x98\xa8\x1e\xb3~\xbdH\xcdS\\ \xd7\xb1(\x00o\x84XZ;"v\xa0zkI[\x96\xe4+\xd6\xf2\xe8r\xd8\x90\xe4\xfc\xbe\xf8\xad\xd5\xd7\x86\x07\x9d~l\x0b\x06\x14W\xcd\x12W\xe4er'
        b'\tk\x1f.\xb4\xec\xa2\x03\xbe\xc3l\xe0\x12\x90\x89H\xb0\xe8`#\xb1\xb0\x91\x80\x07^\xb4\xde\xf7@I\xf8\xf1}\t\xea"\xe6\xef;\n\x1d\xdc\xd3\xfd\x85;\xfd\xf4\x88\xf8;)G\xcd\x80\xfb\x19[8\x1b\xca\xb6\xe9'
        b"\xcdY\xc4@\xf6\x11 @\xa0\xe8\x0b\xbc\xe2r7!\x82\x91T`\xe4?f\x10'\xa9V\xa7Z\x9cf\x1a=\x90\xf0V\x1f=\xdf\xb8\xd2\xa4H\xe0\x1c|\x8bU&&\x17n\x9b\x7f\xa0\xf3G\xfb\xec\x05\x8c&*\x8d"
        b'J\x83\x86\x88?\xd4-\x90\xa4l\xc6\xea\xe3\xef;\xa8"K\xe0\x97%\xb2pU\x14"OtP\xa9t\xd3 %W=\x8e\xc2R~\x8cS>\xff\x03\x11w.*\'{\x10\x12NO6\xe3\x10#\x88@\xe9\x96\xe1'
        b'\x86\xd1On+\xac\x869L\x16;T\xa8Ezs! \xa2L\xad\xc1\xd2w\x9bkE\xb8\x17\x90\x8e\xcb\xf9\x94!\xb0\xe6\xf0\xebK\xdd_\xbdmJ({\x9d\xfd\xe9\xb0Y\xa8\xd4\x1d\x184B\x1f\x10\x8bJ\x19r'
        b'\xa8\xd8\x16\xb0\xd2\xa0\xda-\xec\xe42\xe9\xe1\x8c\xa7\xa8$2\xfaS\x84\xdc1^(\xf6p\xd5\x19~\xba{\x08v\xb3\xc5\xcfE\xd4O\xebVe\xe1\x886\x86u\xcap\xeb\xc7T\xdc\xa1\xda\xb9\x8a\xbd\xf1\xc0\t|\x99'
        b'\xd2\x93\xc22\xa8\xfa\xab\xfb\x07\x0c\x03\xc6C}\xce\xeb:(\x07\xc2m7\xf0\x08y\x9e?|i(\x85\xb1\xe1\x99\xdd\xf1\xb2\xb0mq\xdd8\xfb\xe96\xcd&\x03\x11\xa1\x8d 6\x02\tP*]\xc3\xfd\x10\xf6F\x0f'
        b'\xd5LH\x84n/j6OP\xe3j\xe2l\xa2\xf9KS=G_\xffQ\x1f\xb7\x1a\xe5\x0cfx\xcas\xe6\xdezQ\xf6\x02T\xd1U\x12\xfb?5ch.hnZFH\xbb\xc0\xe5"\xbf\xeaV\x99\xd0\xa9\xab'
        b'\x0b\xb5\x8e\xe7\x14\x04\x9eO{\xd7\xb6\xbd\xe5\xb8u\xf5\x8e\x06\xfb\xa8\xea \xf7m\xdc\x82U\xa4B\x87\x8bzP\xe4\x11\x98\xdd\x9bv!\xd0\x19\xca\x9ar\x8d\xca\xb6FH\x10\x91Y\xdf\xef\x87\x86\xe0?\x10\xd3\x9b\x8d\xb1'
        b'\xf3\xbe+L\xaeZ\xfd|T\x0f\xdf\xff\x03\xb6\x03\x9ao\xcb=\x86\x9b\xc3EaI\x80q;\x94\xd5\x1d\t\xc7\xec-\xad\x1d\xd8\x8a\xd1\\\xcb\x8d\x83\xc7\xe5\x16[\xa6\xfag\xb7\x8e\x1f\xf6\x0c\x85\x8dF\x1b\x9f\xd0\x1du'
        b'\xbd\x99\x02\x10\xce\xb0\x94\xf2Gpl/\xbfr\x92(\xeeo\xef\xe3\xc4y\x13W\x02\xbf\xae\xea2n&\xd2\xc2{68)\xcf\xec\x7fhC8\xa8\x8b\x87\xeaW+#\x01\x9a\xc5N\xedb\xdb\xfcS\x80H\x8a\x1c}'
        b'\xbc0\xec@\xf1\x18\xfal\xb3\x83\xf7\xb4"^\xfa\xca\xb3\xc2]t\xb7_*\x0c\xb0\xd9\x8f\xa6\xdc}[P\x12\x91\xf5\xf3F\x85\xc1\x0ek,\xa4\x8b\xf5V&\xd8\xeb\xd01\xbe$\xc8=\x85\xa8\x04\x8b&\xc4\x04A#'
        b"\xaf\xfc\xc1\x0f\xb9H}5'\x15\xd5L\xd4)\x88\xf6\xf8y.\xa4\x00<e<+\xd3\x95O\xbc\xa91\xe06N\x8cP^\x11\xfb\x03m0V\xc3\xc2\x8c\x98\x17'\xb1\x14\x89\xe8\x84\xbe\xf3\xd8\x02\x9e\x9cK\xff\x852"
        b'\\\xa792\xb1\xa1\xefY\t\xc9\xa0\xd4\xad\x02\xf7>\x821\x16W*y\x0bT\x7f\x95\x96\x86\x84\xf7\x1f\x1d(4\xfb\x05\x93\t\x1de\x8eH&\x9b7\xc5R\xf2\xc2\xea1\xf5\x99\xb28+\x86\x8e\xb9\xe5\xf2\xf9\x02Y'
        b'q\x8cR5g\xfaX\x1d\xee\x896\xb6\xc2\x10\xe5\xc6\x86y\xfdP\xff\x95\xd4"%\xb0\xb2\xa9\x82\x94T\x0f:\x12&\xd1TC\xae*\t\x9c\xb8M\x8d\x04P\xbe\xfb\x1f\xbd\x18\xbf\xa8\xbd\x1dp\xdf\xf1\x0c\x9b\x9c6O'
        b'\xae\xbf\xb6\x1a\x9a\x88a\x1d\xd7\xf5\xeaGt6\xa4\xbd\xf8`}|\xa8\xa91\'\xc8k\x92{;|\xe1`w\x01\xd9\x8f\xde\x8bl""\xc1\xf3\xb0\xc7U\x0cU\xce\xb1\x9aov\xc8\x8b\xecg7!+\x80p\x0f\x1d'
        b'\xc7<hMq\x0f\xe0Zzu]\x83\x0bd\xb6\xea\x0f\xc0\xa7\x0e\xa6\xd3!%\x87\xcf\x9f+3UU\x18\x0f/\xe4\x98\x8c;\x1a\xcc\xa7{\xe7\n=\xe3H@\xd9D\xdfo\x91\x9f\x81\xa8\xb7\xf25c\xf5\x89\x0c\x01'
        b"\x9b\x17\xd6\xc1\xb9\x91,=\x8f\xa1\x13\xbc\r\xf5)8\x01\x089\x9e(\xc5F\xf2\t':\x08\x0b_\xfej5N\xfa\xb2\xcb\xf7\xc9\x0e\x89\xae\x13+*\xcd\xa3b\x90\x0c9|x86U\x84\x04\xe7\x19\xc6}\xcb\xd7"
        b'D\xd9C;\x06RE\xb92y9\xcbb\x12\xf1\x13\xc2d-\xa9\x03V\x94x\x8f\xbe\x00p\xa6x\xddSV\x85,g<QU\xa6\x87s\xb9\xfa0\xf3\xf3lyS\x9c>\xe6Ar=\xa9\xea\x9a\xcf\x1d\xc9d%'
        b'\xc7?\xb4\xfc\x93\x866N\xc5\xe8\x14\xc7\xda\xd7\x0c\x03\xb7\xa2\xa0\x0c\x18\xf5\xc2\xfa\xd5Z.\xc2\x83\x1bL\xba[\x04\x17\x13\x8c\xaa\x06\x95 [\xed\x05\x84\x9a)C\x16@\xd0\xa61\x99[\xadE\xfbl\xd3\x8e\x1d\x10\xe0'
        b'\x0cm\x9ej\x03S7\x94W6\xf23wxn\x14\xb2M\xee\xb6\xee\x14\x0c\xc7\xdf.3\x84\xed\x96@\xf5\xad\xc6gp\xb6\xbb\x88\x8c\xb1\xdaa\x94u\xbd\x06a<\xf8~\xb2\xbe\x80\x83\xd0\xd6\xe0;jF*\\a'
        b'"\x844\x10\xf5{\x90(\'\xfb_\xf0\xd3Y\x9e\xb9$\xc6\n@\x9c\xe8\xa0B\rk\xf4\xfc\xacd\xd0\xc0\xdb\xbcUS9\x97\x19\xc5\xce]Tmd\xe5\xcf\xfd\x97\x94w$\xc9\x1fa\xa3\x0e\xbe\xaci~\x9e\xe0c'
        b'\xd8\xbc\xbe\x8di\xa5\xd6\xcc\xc9O\xab7\xf8\xf5\xdb\x8a\x92\xc6\x15\x998\xab\xb6d\xf2\n\xf0\xac\xdcmk{\x05\x89\x80\xe9\x9e\x0bC4{aK\xdac\x85\x16\x1c\x1e\x976\xe7\xf1\xbfD@\xda\xc3\xa3\xd7!\xfb\xa9*'
        b'x\xf5\xbf\xe5l\xa6\n\x9a\xafQ\x80\xe0\x82b\x86\x99\xcf\xccD\x12\x95^E7\xaf\x8dz\xbe\t9\xc05\xe2\x9f\x08\x98\x1b\xb3\xfb%\x0b\x9d\x00%\xcc)\xe7x,\x08e\x18\x91\xf4r\xa6\xf6\xb0\x0f\x9c\x0c\x1e\xcc\x97'
        b"%\x14%\xc6C7>sav'\x05\xd3,\xddV{J\xc9<z\x1d^j)e1n\x13\x01\xa3.\x01d7h\x1e\xc1\x86\x9f\xc1\x8d\xed\xb6y}\x7f\xe3tm\xf1,o\xc0\x9e\xa4\x02K\xd0\xccr\x1d\xcc\xfc"
        b'\xcaD\xa8\x03\xbc\x911\xb2\xe1\x88:hV\x90\xcc\xa1\xb9\xee\x8e\x13k?\xdd\x16\xa6\x04\xa2+\xf3\'=D\x17\xabd\xdf\x0e:\xa1,"\t\x18\x14w\x9e\x9e\x97[:{3\xf5\xd85E\xc5P\x9ej\xf6iT\x93'
        b'\xba`9\xc39\x92\xaf-\xf1\xc4\x14\xb1L}\xbe\x9e\x13\xe7\xd4\x08_y\x99\x8ev\x18\x12\xa3% \xc5\xf9\x86F\xbb^\x0c\xe5\xff\xe6\x1d\xb6u8\xcc,\xa6\xc7\xeb\xcc\xe6\xefg"\x13\x8d\x95k\xe4\x88x\x92\xa0\xf5'
        b'\x91B\';\xe0R\x0b\xf6\rFYll\x05\xf2"\xec\x8f\x87<\x99zJ\t\x1f\xd6\x07S\xa5{W\xde\xbaq\xf4\x05\x98\x1b6>\x13\xb2\xe9\xaa\x91\xb5\xeaq\x9a\x00uH^wl\x0f\xbeIJ\x04j1X\xa3'
        b'X7\xac<\xdc\xfe\xa2\x02r\x92\xbd\x8d\x0c\xdf\x80%kgR\xa0\n\x02\xb3\xb4\x1f\xce\xe6\xa4\xae\x84 g\xd9\xec\x00S"\xf3b\xa1I3\xb4\xcaMHw\x1a7}\x8e\x82\x16j@;\x10\xe0\xe4\xdc<\x8d\x8dP'
        b'\x19\xbe\xcb\xf6\xa7o\xd5\x10B\xd7K\x8d\x88 }Ze\xa8\x0b\xba\x1aP\xc2a\x14\xaf\xecnF\x1d|0M\xb8\xb97\x83\xac\xa8\xb1\xc1\xbc\xf91\xc9:\xa5\xf6{\xf94\xc9\xb7B\xbcM=\x7f\xfc\x89\xfd\xcb\x17\x86'
        b'*\xb3x\x90\xc6\xdc\x99f.\xe5IgR\xd0\xed\x15\xc9\x1b\xcb\xf7\x19\xe4%(\x10_\x07\xb1\xbd=k\x01\xcc\x8e}H,\x18\xe4[\x8f\xcem\x13x/xg\xa3\xdf}$h~\x81\x91\x0f\xba4\xd0\xac\xf6@V'
        b'\x0e\xc6\xdcb\xd2\x8ex#,\xce\x1a\xe4\x8e{\xd3\xade\x93\xa7\x90 K\xcd\xa6I\x9cn\x1c\xcb\xe3\x90\x03\x96*S\x9c\x90\xf6\x9b\x98%\xfbO\x81z\xf8\xe3\xcc\xa8i)\xf9\x19\x01p\xa3\xab\x99\xc6\x16\xc2\x89\xb5\xe9'
        b'AG\xb5\x9d/1\x95\xfcCB\xe2\xd6\xf2\x19\x01\xd8\x9bC\x9a+*\xc9\xe5M\xad6\xe9\x91\xedV\xffQ\xca\xf8\r\xf4\xc9\xd7\xd5V\xaf\x0e\x95HC\x1a\xaf\x18\xad\xe7\xb6*$I\xa5M\xc1\x83\xa3\xc5\xbf\x85\xb5\xa5'
        b'\x80\x92\xa8\xb6\\>\xcb\x93\xb9-\xd9\xf0\x12ls\x057\x9a\x9fW(\xe2\x9cc\x02\x16\x89\x1c*F\xd8jw\xc5\xc5\x1b\x86\x16\x7f\x84Q\xbckO\x9a\x82\xe1X\x9fE#\x84\xe0An/\x877\xb9\x07K\x1fq\xdd'
        b'm\xc9\xce\xd1z\xfaN``\xcdV\xed\xcdnL\x89>%\xc0\xb0\x8f\xa9\xfc\r\x16\xdc6!&\x05\xfd\xc62i\xf1\xa00a\x1c\xadZ\x12\xae\xb6\xe3\x05w\xb8f\xb9\xa7g(*h]\xd2(\x89\xa1\x1f-P1'
        b'A\x94%\xb6\xe7b\xbdb\xaa\xe8\xdej\x12\xacoF\xf3\xb2\xa6r\xa5l\xc5=\xdb\xd6S\xd4\x95$\xdf\xb0\xb3\xf6m\x94fNO;9\x93\xd1H\xeev0\xa6\xe2\xcb!:Xg\xc3\x0c\xcc\xf7\x0c\xaf\xcc8II'
        b"\x8bV\xb7\xc0\x82\x0b\xf7X\xdb\xb5#\xe0f\xc8\xca\xa3\xc6\xcf\xdb\xfd'\x00\xcc\x04(\x94\x88v4h\xef9j\xcb\x82 Q\xaf\xbf,\x91z\xd3\xaeh$\xf2h\x83\xfb\x7f2\x7f$\x08mU\x07\x07\x8b\xa0X\xaao"
        b'\xba\x80\x19\x9c\x9d\x83\x90b\xff\xb2\x96\xb1K\n63\x15\xb7Q8\x17\xaf\xcc\xea\x01\x1da\x13\x8c\x0f\xbb\x16\xf7E\x87\x9a\x93\x11\xa7\xbdp\x84\x89\xcf\xb6\xefK\x8d\xe1\xe0\xac\x9e;R]\xc5\x14\x02$$\xf2\xeb\\g'
        b'+\xaftu\xf8KY\xa2\xcf\x0b\xd3/\xbf\x05Tr\xeeZiA\xb62\xaa\xb1\x92\x9b\tE"\xa04\xe00\xce}chI\xe0\xe8\x86\xca\xfe\xa3:\xd1d\xb7\xbe1\xe4\xcb\x14|$\x85;\xa8\x1d\xe3I\x94k>'
        b'\xe0\xd2\xc9\x8b\xcf\xa2\xb8J\xb6\xd5\x82\x1739\x1d-\x1f\xf3a\x8c\xd5\x02\xf7\xcc\x04!\x85O}\xd3.\x9c\x13\x81\x9d\x00\x80\x8b\xf4\xb5d\x03%{\xc8\xaa\x1a\xc6\xd4\x83#\xd6\xbc\xc2`\x8b-~\x11GG\x90\xa8T'
        b"\x06\xc4?\x8e[\x86\x13\xbeK\xf0\x0b\xb3\x18j\x154[\xd6\xff\x8b ~\x9a\xf8\x80\xebpb\xd6\xbb\xcb\xaa\x18'l\xd3\xc4a\x03\x83\xca\xf0N\xa3+\xf1\x00Q\xb8{-\x11\x8f(\xb5\xcc\x13\xc3\x81t\xc73\xae\xd6"
        b'\xbe3\\7\x88\x0bV}\xc7\xeb\xfeP\x9b%:R\x9a\xe7M\x18-\xec\xd5\x06\x8d\xdb\xeau\x82\x93t\xc5\x83`RK\xcd"d\xc4\xe6p6\x05\xf0C\xaf\xebwO\xd2\xd0h\x04\x18\x96\x97\x90\xf1\\\xfd\xce\xa7\xb8'
        b'\xdbs\xdf\xfdqz\x06\x1bAJ\xd2\xd8j\xa8\xe8\xb4\xa7c\xc9N\\\xe8\xb0\x8f*\xea\xe0{\x90k\x8e\x17\x98\xdb\xacW\x16\x9a\xd7%\x86M\xaa\xb5\x0bt\xe1\x84,\xe4\xc7q\xe1\xc7GC df$\xf2\xfc\n\x1b'
        b'\xb1\xe3\x89\xdc\xf8\xae%\x88\xed\xfb\xe5x/)\x17cR\xd6\xb1\x8e8\xb3\xb4h\xfe\x02\x07b\x88\xfa\x1f\x9e\xb3\x90\xdd\xee\xf2\x13\xa1\x0c\xc4\x84\x92\x14m\xb3X\xe1\x81\x83c/\xcfp\xd4\xc1\x1bH\xb6\xae_$\x8dp'
        b'\xdb\to@\xd9\xa9S\xd1\xf0\xe5\xf8p\x05V?h\x17\xfe\xe3tz6%*K#G\x06w2\x05\xa2D\xb5B\xbb\xcbf6\xe0,%!\x1fA\xd7\xcc\xac\x92#[W\xbe\x81\xa7\xa2\xa5\xc1\rK\xbfW\xf2\xda'
        b'\xd6\x97b\x90#|\x15\xcdrl\xd1c\x8f\x06F^\x9c-\xc4s\x90\xc1\x8e9Q\x9c\xa2]\xff\xab\x12\x06\x19Y\x08\xea\x97\xec\x16:\x13\x1c\xe6;\xa2\xd2\xb7H\xce\xc06\x8f\x01\xeb\xb7\xee\xa3\x92\xa0\x86\xea\xc4\xd3\xe2'
        b'\x90d\xcd\xd4?c\x00\xd6yrg\\\xbf\xf5u\xe4\x0cz+|\xb8\x8d\xe4\xf9\xb2m\xe5\x10\xc4\x8f|\xf6(\xc5\xfcv\x83\x9c~\xd9\xe0\x90\xc6\x10\xf6\xd3F\x99\xa4\xf7\rU\xcc\xdbcZo\xefG\x1a\xe0\x85.\x00'
        b'\xf0\x81^\xc4\xe5\xbb\x80\xb7\x15\x171\xcdf\xe4\x93i\xf8\xaen"W\xcdv%\xb7\xf0\x9cB\xc8!\xf2N\xb3\x9c\x19w\x9e3/*\x90%\xda\xf6\x1689;+A\x1a\xbc#\xf8\'\xc4\x0e\xa5\x83\x8f)#"u'
        b'?\x15*\xb1\xb7\xf9Ck\xdd\xcc\x0b\xb9\x00\x9a\x15;\x1eYFb\xdc\xb3vpk"\xe3",l\xec\xa1\x9fT\xd3m\xaa\xfc\xa8\x08\xfdT\xd4O\xaa8\x9cT\x0b\xf2\xa3j\\\xf5\xa3\x18F\x8e\xcb\x87\xfa\xc8\xb6\xd9'
        b'\xd2\x1c\xab\x12\x04\x06\x93\xfa\x85\xf6\xb7B\xcd\xdb\xca\xb7\x9eL+\xeb<\xa2\xd7\x98\x9c\xb9\xda\x02\xf2\xcdw(\x8b\xb5\x93bR\xfaV\xde1>\xf4k%\xdcX\x0c\x8cwRs\x07\xa3\xd3\xb4\xae/R\xd2\x12\xb6g\xe3'
        b'g{\x02*\xd9\xcc\xbb\xd9\xa88\t\xd0!V\xd8\xb9\x0b[s\xb0.3\x82\xfc\xec~\xd8\xa9\xb3\xcd\x84\xf6\x13!\xc4\xdd\xc4\x8a\xfaKp\x83\xea^Y\xa5\xf5c\x96"\xe6\xda\x04\xca\xb6\xf57x\x16\xf5\xed\xb3\x0c<'
        b'\xe6,W\x84\x15\x00sY\x00\x84\x19Oi&\x07\xc6C\xa9\x89h\xfe\xd4g=\x97\xe2\xab~\x98\xc6\x13\xb1\xb1\x92\x01_\xe1I\x075*\xc9\xce\xc5\xf0\x9e\xae\x0fu\xa1\xdf\xc0\xe8o\x1b\xdcA\xe5\x1d\xe7j1u\x04'
        b's^\x18/\x95\'\n4\xbc\xb8b\xf6i#\xe2\x97\xdc\xa3N \x80\x1ep\xe4~\x86\xaa\xbf\\\x10i\xc4\x81\xb2\xe2L"\xd3\xf3\xda\x000\xa0B\r\xc3\xe4\xe47\xa3v\xd4\x86\xab\x19\x97\x16\x97.\xeb\x01\x8f\x132'
        b'\x8f\xc8A\x16\xf1\xfdK7\xe0+=F4\xf5\'\xac\xbc^~\x1aE\xe6\xce\xe4 Q\x12\xd0\xc6\x93\xaa\xff\x0c\xb1\xf0e\xc7\xc3\x12\xe5\x93\x883\x9fb\xd1(\xc4"\x9a\xf5{\x11\x02#g\x9c\xb5\xcb\xe4\xfa\x0cb\xe9'
        b'dTTz\xdd\xc1xu\x9f\xab\x03\xfdR\x0c\xc2-\xc8q\xc7\xe7\xc7q\xdc|\xd1\xc1\xd0\xfav\xec\x82;w\xa2Q8\x9b\xd8q\xd5\xbf\x17\xf3\xa5\x85HB`!\xcd\xdb5F\xab\xefmm\xde\xb4\r\x13\x18ot'
        b'Q\xe1[\xbbPa\xb9`-\xe6V(Ig\xc4\xcc;\xb8s\x12\x88-\x9a\x10\xf5j\\\x14\xb5] \x8b\xe2\x18\xf5z0\xd9l\xebW_A\xb5_>6|\x04\xba\xd2p|>]\x1aS\x1cF9\xe8\xa3H\x90'
        b";p\xd2\xc9O&7/\xc5\xbdNO>3\xe5\xdb\xa5L\xd4|Y\xb9\x97\xe6+p\xc0\xa3\xd4'\xf5\t*\xbf\xe4\x07\xf0\xbc1t\x06\x8f\xf9\xb5\xd4\x03\x94\xfb;\xc5\x81\xac\x13F\x89\xe1!%\xe3!A\xd8\xc5o"
        b'\xe3\xce\xde\x96Jq\x02\x00B\xd6\xbb\x91\x0f\xfe\x95\\\xb3\x8dF\x12^&\xd9X\x167\xfa\x88\x9d\xa9\xb3\x15\x18\xd1\x0e\x97K"E\xc3<=\x93\x19\xac\x10\x1e\x0c\x0e\xbf#\xcc\x1f\x16K\x9a\xbc\xea\xb4\xeeE\tq\xf8'
        b'*+\x12%\x93\x80%\xef\xb5lm\x83m\x14\x0c\x9b\xfc\x94\xf74\xb3\x06\x8e(\x0b\xf4\xb6\xe2\x1d\xdb8\x83\x1b\x80\x16}\x8a\xc2o\x0e5\xa6\xfc\x8c0y\x14\x00\xe8\xb8\xee\x97\xc7\xc5\xc4\x1e}\xf6\tb\xe4\xde)\xa4'
        b'\xa89\x84WX\xbb\xf75\n\xd5\xa2\xee\x7fO\x95%*&\x0f\xd4,\x85\xe1\xce\xc7:J\xc7\xb6\x04\xf7n\x0e\x18\x08\x13/\xc3\xba\x0f\xe0,[.73\xa7q\xd9}v\x90(\xc1(4\r\x8e\x9c\x88X]\x81\xdc'
        b'\xda\xb5\xbf\xe2A\xfc1S1H\xa0\x95"\x03\xd3$p\xc0\xb7\xbfx\xb0I^y\x9d\x10\xcc= \x1f\xb1\x99\x97"\x194O\xdd\x9c\xf4:\x9e\xfbn#R\xbf\xc6\xda\xa7\xa3\x08\xe5\rk\xdeJ\xaah\xcf\xb8\ts'
        b'x0\xd8~\xae\x06\xa2\xe3\x1dX\xac@\xc3\n\x17j\xea\x9cn\xda\x89\x9d\x0c\xfb\x18\xfa\x93L#\xdcB\x9f\x98b\x1f.\xe58A\t\xc8\x15;\x1c\xb7\x12\x18\x0b\x07\xb2\x99V\x9d\xf6$\xff\xf2\xe5\x1f\x11\xb1^k\xb9'
        b'\x1a\xb9L\xd3\x1b\x0f\xfd"\xa9=\xcf\xaaH\xc8\x82\x8b\x15fp\x896\x7f\xdd\x8d/1\xa5\xd5<\xdc,\xfc&\xb8\x02\xdc\x9c\xe34Ad\xbf\xa7\x85\xd6\xdfp\xa8\x00C\x16\x10\x10\xfaV\x1c\xc1\x8agZ\xc3\xaf\x85\xe2'
        b'H\x1f\xdcH\xf0\xda\xbdW\xe4\x9c0a{\xe1\xf8I\xa1ho)\xa0\xe3qbq\x10\xa7]f.=LX\xfdcQ\x14\xb5c\xd8\xda\xdd\xcaE\x18\xb4\x0f \xa2^\xe3\xc9l \x0bla\xe5;\xba\xebi]@'
        b"A\x83S\xa8x\xdd\x13I\x87\x8b\xd7\xf2\xa1\xb1\xa1\x98)Z\xfb\x15\xc20\x96\n\x1b\x0coLE-'O\xfd<\xcey\xa0\x80\xdbQ\xb5\xb4\xcf\xa2H\x11\xea\xc3\xc5\xdd\x01\xd6T\x10#sm&\xbf\x9d\xc1}+\n"
        b'u\xfe\xdf"\xcf\xbb*L\xa8\xbb\xf37\x1b\x06\xb6\x91\xf8r$\x19,m\x11\xfe\xf9\x8a\xa3^>\xd9\x98u\x97\xcb\xe9\xb3a\x10\x9f\xbc\xeeB\xe1\xc2\x8f\x80\x0f\x05\n\xeb\xe7E\xb5\x9c+c\xbf(\xb6X\xce\xe2\xd6\x00'
        b'\xf5\x00\xc8\xeb\xdb\xec\xbb\x90\xa3\xef\xedr\xa7\xe8\xa6\xf5\x82\xa1\x19#Q\xe9\x1b\x8f\xf8\xed~\xa1\xf3\x1e\xb6z\xd5\xa9W\xfdv\x80\tT*\xc4z\x89\xab\x9d`\x01\xcd96\xeci$-RJ=\xf6D4o\xf4['
        b'\x9e\xcad\x8c\xf5H\x9a\xe1\x03\xb5\x01\x81\x06\x17\xd3\x94\xcf\xb7\xa0)\xe7\x9a\xbb\xe5\xfe\x9a\xf3\xf9\x93\xc5U\t\x0b\x0b]u\xe4\xdf\x84\xc9\x1b\xf7j\xcb\x12\xfbc&6\x91\xf7V\xa0\xaf\x15\xcd`q0A.V8t'
        b'p?Z}\x87\x0fX\xe9\x1b\xea\x06\x1du}\\\xfb\x99a\xa3\x1c\xb4\x0e\xcd\x81\xd0\xa0\xd8\xc4\xcb(\x17H\x9c=\x9e\xe7t\xf5l\xf25\xfd%\xb3\xb5\xeb\xce\xdf\xd2\x0e\x1f;\x19\x865!\xa1\xb5\x13b>M\x8c#'
        b'\x81V\xcf\x95\xe1R\x97JZ\xbd\xf4\x06\xabD\x16\x98\xb6\xe1\xac\xd2\xc7]2\xe9O\xd2\x9b\x08N\xbd\xc6\xc7\x14\xd7\xe4\x86^1z\x8fu\xe6\xa9=Z"rW\xb4\xc4\xac\xac~j\x8d\xb2\x8bv,\x06\xa5"\x81\xa7'
        b'\x08ck\x14>\x9d\xbc\x8b}\x8c<;\xf4\xfa\xf1t\xbeW\xf9\x1f\xbd\xb4\x1do\x88Kx*%O\xb8\xf0\x9b\x00\r\xb0\\\xc5`\x8a\x0f\xb5\xf4COd&m\x13\x8de)\xbf\xbb6j\x1a\x16\xaci\xfd\xe9\x01\x00'
        b'\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00'
        b'\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x06\x00\x00\x00\n\x00\x0e\x01\x12\x01'
    ))
